@@ -1752,7 +1752,7 @@ namespace Magick
   void linkImages( InputIterator first_,
 		   InputIterator last_ ) {
 
-    MagickLib::Image* previous = 0;
+    MagickCore::Image* previous = 0;
     int scene = 0;
     for ( InputIterator iter = first_; iter != last_; ++iter )
       {
@@ -1761,7 +1761,7 @@ namespace Magick
 	// the linked list to fail.
 	iter->modifyImage();
 
-	MagickLib::Image* current = iter->image();
+	MagickCore::Image* current = iter->image();
 
 	current->previous = previous;
 	current->next     = 0;
@@ -1784,7 +1784,7 @@ namespace Magick
 		     InputIterator last_ ) {
     for( InputIterator iter = first_; iter != last_; ++iter )
       {
-	MagickLib::Image* image = iter->image();
+	MagickCore::Image* image = iter->image();
 	image->previous = 0;
 	image->next = 0;
       }
@@ -1795,13 +1795,13 @@ namespace Magick
   // The options are copied into the object.
   template <class Container>
   void insertImages( Container *sequence_,
-		     MagickLib::Image* images_ ) {
-    MagickLib::Image *image = images_;
+		     MagickCore::Image* images_ ) {
+    MagickCore::Image *image = images_;
     if ( image )
       {
 	do
 	  {
-	    MagickLib::Image* next_image = image->next;
+	    MagickCore::Image* next_image = image->next;
 	    image->next = 0;
 	  
 	    if (next_image != 0)
@@ -1825,14 +1825,14 @@ namespace Magick
   template <class InputIterator>
   void animateImages( InputIterator first_,
 		      InputIterator last_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::AnimateImages( first_->imageInfo(), first_->image() );
-    MagickLib::GetImageException( first_->image(), &exceptionInfo );
+    MagickCore::AnimateImages( first_->imageInfo(), first_->image() );
+    MagickCore::GetImageException( first_->image(), &exceptionInfo );
     unlinkImages( first_, last_ );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Append images from list into single image in either horizontal or
@@ -1842,16 +1842,16 @@ namespace Magick
 		     InputIterator first_,
 		     InputIterator last_,
 		     bool stack_ = false) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::Image* image = MagickLib::AppendImages( first_->image(),
+    MagickCore::Image* image = MagickCore::AppendImages( first_->image(),
 						       (MagickBooleanType) stack_,
 						       &exceptionInfo ); 
     unlinkImages( first_, last_ );
     appendedImage_->replaceImage( image );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Average a set of images.
@@ -1860,15 +1860,15 @@ namespace Magick
   void averageImages( Image *averagedImage_,
 		      InputIterator first_,
 		      InputIterator last_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::Image* image = MagickLib::AverageImages( first_->image(),
+    MagickCore::Image* image = MagickCore::AverageImages( first_->image(),
 							&exceptionInfo );
     unlinkImages( first_, last_ );
     averagedImage_->replaceImage( image );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Merge a sequence of images.
@@ -1880,12 +1880,12 @@ namespace Magick
   void coalesceImages( Container *coalescedImages_,
                        InputIterator first_,
                        InputIterator last_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
 
     // Build image list
     linkImages( first_, last_ );
-    MagickLib::Image* images = MagickLib::CoalesceImages( first_->image(),
+    MagickCore::Image* images = MagickCore::CoalesceImages( first_->image(),
                                                           &exceptionInfo);
     // Unlink image list
     unlinkImages( first_, last_ );
@@ -1898,7 +1898,7 @@ namespace Magick
 
     // Report any error
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Return format coders matching specified conditions.
@@ -1918,14 +1918,14 @@ namespace Magick
                       ) {
     // Obtain first entry in MagickInfo list
     unsigned long number_formats;
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     char **coder_list =
-      MagickLib::GetMagickList( "*", &number_formats, &exceptionInfo );
+      MagickCore::GetMagickList( "*", &number_formats, &exceptionInfo );
     if( !coder_list )
       {
         throwException( exceptionInfo );
-        throwExceptionExplicit(MagickLib::MissingDelegateError,
+        throwExceptionExplicit(MagickCore::MissingDelegateError,
                              "Coder array not returned!", 0 );
       }
 
@@ -1934,10 +1934,10 @@ namespace Magick
 
     for ( int i=0; i < (long) number_formats; i++)
       {
-        const MagickLib::MagickInfo *magick_info =
-          MagickLib::GetMagickInfo( coder_list[i], &exceptionInfo );
+        const MagickCore::MagickInfo *magick_info =
+          MagickCore::GetMagickInfo( coder_list[i], &exceptionInfo );
         coder_list[i]=(char *)
-          MagickLib::RelinquishMagickMemory( coder_list[i] );
+          MagickCore::RelinquishMagickMemory( coder_list[i] );
 
         // Skip stealth coders
         if ( magick_info->stealth )
@@ -1973,8 +1973,8 @@ namespace Magick
             continue;
           }
       }
-    coder_list=(char **) MagickLib::RelinquishMagickMemory( coder_list );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    coder_list=(char **) MagickCore::RelinquishMagickMemory( coder_list );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   //
@@ -2020,13 +2020,13 @@ namespace Magick
   template <class Container >
   void colorHistogram( Container *histogram_, const Image image)
   {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
 
     // Obtain histogram array
     unsigned long colors;
-    MagickLib::ColorPacket *histogram_array = 
-      MagickLib::GetImageHistogram( image.constImage(), &colors, &exceptionInfo );
+    MagickCore::ColorPacket *histogram_array = 
+      MagickCore::GetImageHistogram( image.constImage(), &colors, &exceptionInfo );
     throwException( exceptionInfo );
 
     // Clear out container
@@ -2043,9 +2043,9 @@ namespace Magick
       }
     
     // Deallocate histogram array
-    histogram_array=(MagickLib::ColorPacket *)
-      MagickLib::RelinquishMagickMemory(histogram_array);
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    histogram_array=(MagickCore::ColorPacket *)
+      MagickCore::RelinquishMagickMemory(histogram_array);
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
                       
   // Break down an image sequence into constituent parts.  This is
@@ -2054,12 +2054,12 @@ namespace Magick
   void deconstructImages( Container *deconstructedImages_,
                           InputIterator first_,
                           InputIterator last_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
 
     // Build image list
     linkImages( first_, last_ );
-    MagickLib::Image* images = MagickLib::DeconstructImages( first_->image(),
+    MagickCore::Image* images = MagickCore::DeconstructImages( first_->image(),
                                                              &exceptionInfo);
     // Unlink image list
     unlinkImages( first_, last_ );
@@ -2072,7 +2072,7 @@ namespace Magick
 
     // Report any error
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   //
@@ -2081,14 +2081,14 @@ namespace Magick
   template <class InputIterator>
   void displayImages( InputIterator first_,
 		      InputIterator last_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::DisplayImages( first_->imageInfo(), first_->image() );
-    MagickLib::GetImageException( first_->image(), &exceptionInfo );
+    MagickCore::DisplayImages( first_->imageInfo(), first_->image() );
+    MagickCore::GetImageException( first_->image(), &exceptionInfo );
     unlinkImages( first_, last_ );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Merge a sequence of image frames which represent image layers.
@@ -2097,15 +2097,15 @@ namespace Magick
   void flattenImages( Image *flattendImage_,
 		      InputIterator first_,
 		      InputIterator last_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::Image* image = MagickLib::MergeImageLayers( first_->image(),
+    MagickCore::Image* image = MagickCore::MergeImageLayers( first_->image(),
 		  FlattenLayer,&exceptionInfo );
     unlinkImages( first_, last_ );
     flattendImage_->replaceImage( image );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Replace the colors of a sequence of images with the closest color
@@ -2119,27 +2119,27 @@ namespace Magick
 		  bool dither_ = false,
 		  bool measureError_ = false ) {
 
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::MapImages( first_->image(),
+    MagickCore::MapImages( first_->image(),
 			  mapImage_.constImage(),
-			  dither_ ? MagickLib::MagickTrue : MagickLib::MagickFalse);
-    MagickLib::GetImageException( first_->image(), &exceptionInfo );
-    if ( exceptionInfo.severity != MagickLib::UndefinedException )
+			  dither_ ? MagickCore::MagickTrue : MagickCore::MagickFalse);
+    MagickCore::GetImageException( first_->image(), &exceptionInfo );
+    if ( exceptionInfo.severity != MagickCore::UndefinedException )
       {
 	unlinkImages( first_, last_ );
 	throwException( exceptionInfo );
       }
 
-    MagickLib::Image* image = first_->image();
+    MagickCore::Image* image = first_->image();
     while( image )
       {
 	// Calculate quantization error
 	if ( measureError_ )
 	  {
-	    MagickLib::GetImageQuantizeError( image );
-	    if ( image->exception.severity > MagickLib::UndefinedException )
+	    MagickCore::GetImageQuantizeError( image );
+	    if ( image->exception.severity > MagickCore::UndefinedException )
 	      {
 		unlinkImages( first_, last_ );
 		throwException( exceptionInfo );
@@ -2147,8 +2147,8 @@ namespace Magick
 	  }
 	
 	// Udate DirectClass representation of pixels
-	MagickLib::SyncImage( image );
-	if ( image->exception.severity > MagickLib::UndefinedException )
+	MagickCore::SyncImage( image );
+	if ( image->exception.severity > MagickCore::UndefinedException )
 	  {
 	    unlinkImages( first_, last_ );
 	    throwException( exceptionInfo );
@@ -2159,7 +2159,7 @@ namespace Magick
       }
 
     unlinkImages( first_, last_ );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Create a composite image by combining several separate images.
@@ -2169,8 +2169,8 @@ namespace Magick
 		      InputIterator last_,
 		      const Montage &montageOpts_ ) {
 
-    MagickLib::MontageInfo* montageInfo =
-      static_cast<MagickLib::MontageInfo*>(MagickLib::AcquireMagickMemory(sizeof(MagickLib::MontageInfo)));
+    MagickCore::MontageInfo* montageInfo =
+      static_cast<MagickCore::MontageInfo*>(MagickCore::AcquireMagickMemory(sizeof(MagickCore::MontageInfo)));
 
     // Update montage options with those set in montageOpts_
     montageOpts_.updateMontageInfo( *montageInfo );
@@ -2186,9 +2186,9 @@ namespace Magick
     montageImages_->clear();
 
     // Do montage
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
-    MagickLib::Image *images = MagickLib::MontageImages( first_->image(),
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+    MagickCore::Image *images = MagickCore::MontageImages( first_->image(),
 							 montageInfo,
 							 &exceptionInfo );
     if ( images != 0 )
@@ -2197,7 +2197,7 @@ namespace Magick
       }
 
     // Clean up any allocated data in montageInfo
-    MagickLib::DestroyMontageInfo( montageInfo );
+    MagickCore::DestroyMontageInfo( montageInfo );
 
     // Unlink linked image list
     unlinkImages( first_, last_ );
@@ -2212,9 +2212,9 @@ namespace Magick
       }
 
     // Report any transparentImage() error
-    MagickLib::GetImageException( first_->image(), &exceptionInfo );
+    MagickCore::GetImageException( first_->image(), &exceptionInfo );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Morph a set of images
@@ -2223,12 +2223,12 @@ namespace Magick
 		    InputIterator first_,
 		    InputIterator last_,
 		    unsigned int frames_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
 
     // Build image list
     linkImages( first_, last_ );
-    MagickLib::Image* images = MagickLib::MorphImages( first_->image(), frames_,
+    MagickCore::Image* images = MagickCore::MorphImages( first_->image(), frames_,
 						       &exceptionInfo);
     // Unlink image list
     unlinkImages( first_, last_ );
@@ -2241,7 +2241,7 @@ namespace Magick
 
     // Report any error
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Inlay a number of images to form a single coherent picture.
@@ -2249,15 +2249,15 @@ namespace Magick
   void mosaicImages( Image *mosaicImage_,
 		     InputIterator first_,
 		     InputIterator last_ ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::Image* image = MagickLib::MergeImageLayers( first_->image(),
+    MagickCore::Image* image = MagickCore::MergeImageLayers( first_->image(),
 			 MosaicLayer,&exceptionInfo ); 
     unlinkImages( first_, last_ );
     mosaicImage_->replaceImage( image );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Quantize colors in images using current quantization settings
@@ -2266,36 +2266,36 @@ namespace Magick
   void quantizeImages( InputIterator first_,
 		       InputIterator last_,
 		       bool measureError_ = false ) {
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
 
     linkImages( first_, last_ );
 
-    MagickLib::QuantizeImages( first_->quantizeInfo(),
+    MagickCore::QuantizeImages( first_->quantizeInfo(),
 			       first_->image() );
-    MagickLib::GetImageException( first_->image(), &exceptionInfo );
-    if ( exceptionInfo.severity > MagickLib::UndefinedException )
+    MagickCore::GetImageException( first_->image(), &exceptionInfo );
+    if ( exceptionInfo.severity > MagickCore::UndefinedException )
       {
 	unlinkImages( first_, last_ );
 	throwException( exceptionInfo );
       }
 
-    MagickLib::Image* image = first_->image();
+    MagickCore::Image* image = first_->image();
     while( image != 0 )
       {
 	// Calculate quantization error
 	if ( measureError_ )
-	  MagickLib::GetImageQuantizeError( image );
+	  MagickCore::GetImageQuantizeError( image );
 
 	// Update DirectClass representation of pixels
-	MagickLib::SyncImage( image );
+	MagickCore::SyncImage( image );
 
 	// Next image
 	image=image->next;
       }
 
     unlinkImages( first_, last_ );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Read images into existing container (appending to container)
@@ -2303,30 +2303,30 @@ namespace Magick
   template <class Container>
   void readImages( Container *sequence_,
 		   const std::string &imageSpec_ ) {
-    MagickLib::ImageInfo *imageInfo = MagickLib::CloneImageInfo(0);
+    MagickCore::ImageInfo *imageInfo = MagickCore::CloneImageInfo(0);
     imageSpec_.copy( imageInfo->filename, MaxTextExtent-1 );
     imageInfo->filename[ imageSpec_.length() ] = 0;
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
-    MagickLib::Image* images =  MagickLib::ReadImage( imageInfo, &exceptionInfo );
-    MagickLib::DestroyImageInfo(imageInfo);
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+    MagickCore::Image* images =  MagickCore::ReadImage( imageInfo, &exceptionInfo );
+    MagickCore::DestroyImageInfo(imageInfo);
     insertImages( sequence_, images);
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
   template <class Container>
   void readImages( Container *sequence_,
 		   const Blob &blob_ ) {
-    MagickLib::ImageInfo *imageInfo = MagickLib::CloneImageInfo(0);
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
-    MagickLib::Image *images = MagickLib::BlobToImage( imageInfo,
+    MagickCore::ImageInfo *imageInfo = MagickCore::CloneImageInfo(0);
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+    MagickCore::Image *images = MagickCore::BlobToImage( imageInfo,
 						       blob_.data(),
 						       blob_.length(), &exceptionInfo );
-    MagickLib::DestroyImageInfo(imageInfo);
+    MagickCore::DestroyImageInfo(imageInfo);
     insertImages( sequence_, images );
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
   // Write Images
@@ -2338,11 +2338,11 @@ namespace Magick
 
     first_->adjoin( adjoin_ );
 
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
 
     linkImages( first_, last_ );
-    int errorStat = MagickLib::WriteImages( first_->constImageInfo(),
+    int errorStat = MagickCore::WriteImages( first_->constImageInfo(),
                                             first_->image(),
                                             imageSpec_.c_str(),
                                             &exceptionInfo );
@@ -2350,12 +2350,12 @@ namespace Magick
 
     if ( errorStat != false )
       {
-        MagickLib::DestroyExceptionInfo( &exceptionInfo );
+        MagickCore::DestroyExceptionInfo( &exceptionInfo );
         return;
       }
 
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
   // Write images to BLOB
   template <class InputIterator>
@@ -2368,10 +2368,10 @@ namespace Magick
 
     linkImages( first_, last_ );
 
-    MagickLib::ExceptionInfo exceptionInfo;
-    MagickLib::GetExceptionInfo( &exceptionInfo );
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
     size_t length = 2048; // Efficient size for small images
-    void* data = MagickLib::ImageToBlob( first_->imageInfo(),
+    void* data = MagickCore::ImageToBlob( first_->imageInfo(),
 					 first_->image(),
 					 &length,
 					 &exceptionInfo);
@@ -2380,7 +2380,7 @@ namespace Magick
     unlinkImages( first_, last_ );
 
     throwException( exceptionInfo );
-    MagickLib::DestroyExceptionInfo( &exceptionInfo );
+    MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
 } // namespace Magick
