@@ -816,9 +816,6 @@ static MagickBooleanType DecodeImage(Image *image,
   long
     y;
 
-  MagickBooleanType
-    status;
-
   register long
     i,
     x;
@@ -938,14 +935,8 @@ static MagickBooleanType DecodeImage(Image *image,
           }
         }
       }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse)
+      break;
   }
   if (ReadBlobByte(image) == EOF)
     ThrowBinaryException(CorruptImageError,"UnexpectedEndOfFile",
@@ -1655,14 +1646,12 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   }
                   if (SyncImagePixels(image) == MagickFalse)
                     break;
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(LoadImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+              if (image->previous == (Image *) NULL)
+                {
+                  status=SetImageProgress(image,LoadImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
             if (jpeg_info.quantize_colors != MagickFalse)
               for (i=0; i < jpeg_info.actual_number_of_colors; i++)
@@ -1810,11 +1799,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(offset,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(LoadImageTag,offset,
-                      image->rows,image->client_data);
+                    status=SetImageProgress(image,LoadImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -1854,11 +1840,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(offset,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(LoadImageTag,offset,
-                      image->rows,image->client_data);
+                    status=SetImageProgress(image,LoadImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -1890,11 +1873,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(offset,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(LoadImageTag,offset,
-                      image->rows,image->client_data);
+                    status=SetImageProgress(image,LoadImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -1932,11 +1912,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(offset,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(LoadImageTag,offset,
-                      image->rows,image->client_data);
+                    status=SetImageProgress(image,LoadImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -1969,11 +1946,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(offset,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(LoadImageTag,offset,
-                      image->rows,image->client_data);
+                    status=SetImageProgress(image,LoadImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -2002,13 +1976,10 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 return((Image *) NULL);
               }
             image=SyncNextImageInList(image);
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
-              {
-                status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-                  GetBlobSize(image),image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+              GetBlobSize(image));
+            if (status == MagickFalse)
+              break;
           }
         continue;
       }
