@@ -54,6 +54,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/property.h"
 #include "magick/quantize.h"
@@ -377,9 +378,6 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
     offset,
     y;
 
-  MagickBooleanType
-    status;
-
   register IndexPacket
     *indexes;
 
@@ -481,15 +479,6 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
       }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
-        {
-          status=image->progress_monitor(LoadImageTag,y,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
   }
   lzw_info=RelinquishLZWInfo(lzw_info);
   if (y < (long) image->rows)
@@ -575,9 +564,6 @@ static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
     k,
     y;
 
-  MagickBooleanType
-    status;
-
   register const PixelPacket
     *p;
 
@@ -768,15 +754,6 @@ static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
           break;
         }
       }
-    if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
-        {
-          status=image->progress_monitor(SaveImageTag,y,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
   }
   /*
     Flush out the buffered code.
@@ -1215,13 +1192,6 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-              GetBlobSize(image),image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
       }
     image_count++;
     /*
@@ -1351,6 +1321,9 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
     opacity=(-1);
+    status=SetImageProgress(image,LoadImageTag,image->scene-1,image->scene);
+    if (status == MagickFalse)
+      break;
   }
   global_colormap=(unsigned char *) RelinquishMagickMemory(global_colormap);
   if ((image->columns == 0) || (image->rows == 0))
@@ -1873,14 +1846,11 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
     scene++;
+    status=SetImageProgress(image,SaveImagesTag,scene,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
   } while (write_info->adjoin != MagickFalse);
   (void) WriteBlobByte(image,';'); /* terminator */
   global_colormap=(unsigned char *) RelinquishMagickMemory(global_colormap);
