@@ -132,11 +132,7 @@ static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 static Image *ReadMPEGImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
-#if defined(__WINDOWS__)
-# define ReadMPEGIntermediateFormat "pnm"
-#else
-# define ReadMPEGIntermediateFormat "pam"
-#endif
+#define ReadMPEGIntermediateFormat "pam"
 
   Image
     *image,
@@ -272,7 +268,6 @@ ModuleExport unsigned long RegisterMPEGImage(void)
   entry->description=ConstantString("MPEG-4 Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
-  return(MagickImageCoderSignature);
   entry=SetMagickInfo("M2V");
   entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
   entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
@@ -281,7 +276,6 @@ ModuleExport unsigned long RegisterMPEGImage(void)
   entry->description=ConstantString("MPEG Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
-  return(MagickImageCoderSignature);
   entry=SetMagickInfo("M4V");
   entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
   entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
@@ -290,6 +284,14 @@ ModuleExport unsigned long RegisterMPEGImage(void)
   entry->description=ConstantString("Raw MPEG-4 Video");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
+  entry=SetMagickInfo("WMV");
+  entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
+  entry->magick=(IsImageFormatHandler *) IsMPEG;
+  entry->blob_support=MagickFalse;
+  entry->description=ConstantString("Windows Media Video");
+  entry->module=ConstantString("MPEG");
+  (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
 
@@ -314,6 +316,7 @@ ModuleExport unsigned long RegisterMPEGImage(void)
 */
 ModuleExport void UnregisterMPEGImage(void)
 {
+  (void) UnregisterMagickInfo("WMV");
   (void) UnregisterMagickInfo("M4V");
   (void) UnregisterMagickInfo("M2V");
   (void) UnregisterMagickInfo("MP4");
@@ -438,11 +441,7 @@ static MagickBooleanType CopyDelegateFile(const char *source,
 static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
   Image *image)
 {
-#if defined(__WINDOWS__)
-# define WriteMPEGIntermediateFormat "yuv"
-#else
-# define WriteMPEGIntermediateFormat "jpg"
-#endif
+#define WriteMPEGIntermediateFormat "jpg"
 
   char
     basename[MaxTextExtent],
@@ -452,8 +451,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     delay;
 
   Image
-    *coalesce_image,
-    *next_image;
+    *coalesce_image;
 
   ImageInfo
     *write_info;
@@ -494,28 +492,11 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     return(status);
   (void) CloseBlob(image);
   /*
-    Determine if the sequence of images have identical page info.
-  */
-  coalesce_image=image;
-  for (next_image=image; next_image != (Image *) NULL; )
-  {
-    if ((image->columns != next_image->columns) ||
-        (image->rows != next_image->rows))
-      break;
-    if ((image->page.x != next_image->page.x) ||
-        (image->page.y != next_image->page.y))
-      break;
-    next_image=GetNextImageInList(next_image);
-  }
-  if (next_image != (Image *) NULL)
-    {
-      coalesce_image=CoalesceImages(image,&image->exception);
-      if (coalesce_image == (Image *) NULL)
-        return(MagickFalse);
-    }
-  /*
-    Write YUV files.
+    Write JPEG files.
   */
+  coalesce_image=CoalesceImages(image,&image->exception);
+  if (coalesce_image == (Image *) NULL)
+    return(MagickFalse);
   file=AcquireUniqueFileResource(basename);
   if (file != -1)
     file=close(file)-1;
@@ -575,10 +556,10 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
         {
           if (status != MagickFalse)
             (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-              "%lu. Wrote YUV file for scene %lu:",i,p->scene);
+              "%lu. Wrote JPEG file for scene %lu:",i,p->scene);
           else
             (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-              "%lu. Failed to write YUV file for scene %lu:",i,p->scene);
+              "%lu. Failed to write JPEG file for scene %lu:",i,p->scene);
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),"%s",
             filename);
         }
@@ -590,7 +571,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
       break;
   }
   /*
-    Convert YUV to MPEG.
+    Convert JPEG to MPEG.
   */
   (void) CopyMagickString(coalesce_image->magick_filename,basename,
     MaxTextExtent);
@@ -621,8 +602,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     (void) CopyMagickString(p->filename,image_info->filename,MaxTextExtent);
   }
   (void) RelinquishUniqueFileResource(basename);
-  if (coalesce_image != image)
-    coalesce_image=DestroyImage(coalesce_image);
+  coalesce_image=DestroyImage(coalesce_image);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),"exit");
   return(status);
