@@ -194,11 +194,9 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
+    if (image->previous == (Image *) NULL)
       {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
+        status=SetImageProgress(image,LoadImageTag,y,image->rows);
         if (status == MagickFalse)
           break;
       }
@@ -379,11 +377,9 @@ static MagickBooleanType WriteOTBImage(const ImageInfo *image_info,Image *image)
     }
     if (bit != 0)
       (void) WriteBlobByte(image,byte);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
+    if (image->previous == (Image *) NULL)
       {
-        status=image->progress_monitor(SaveImageTag,y,image->rows,
-          image->client_data);
+        status=SetImageProgress(image,SaveImageTag,y,image->rows);
         if (status == MagickFalse)
           break;
       }
