@@ -578,14 +578,9 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
         }
         if (bit != 0)
           (void) WriteBlobByte(image,(unsigned char) (byte << (8-bit)));
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(SaveImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,SaveImageTag,y,image->rows);
+        if (status == MagickFalse)
+          break;
       }
       (void) WriteBlobString(image,"\033*rB");  /* end graphics */
     }
@@ -637,14 +632,9 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
           3*image->columns);  /* send row */
         (void) WriteBlobString(image,buffer);
         (void) WriteBlob(image,3*image->columns,pixels);
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(SaveImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,SaveImageTag,y,image->rows);
+        if (status == MagickFalse)
+          break;
       }
       (void) WriteBlobString(image,"\033*r0C");  /* end graphics */
       pixels=(unsigned char *) RelinquishMagickMemory(pixels);
