@@ -954,12 +954,11 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
   */
   object=0;
   version=3;
+  if (image_info->compression == JPEG2000Compression)
+    version=(unsigned long) MagickMax(version,5);
   for (next=image; next != (Image *) NULL; next=GetNextImageInList(next))
-    if (next->compression == JPEG2000Compression)
-      version=(unsigned long) MagickMax(version,5);
-    else
-      if (next->matte != MagickFalse)
-        version=(unsigned long) MagickMax(version,4);
+    if (next->matte != MagickFalse)
+      version=(unsigned long) MagickMax(version,4);
   if (LocaleCompare(image_info->magick,"PDFA") == 0)
     version=(unsigned long) MagickMax(version,6);
   (void) FormatMagickString(buffer,MaxTextExtent,"%%PDF-1.%lu \n",version);
@@ -1471,14 +1470,11 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
                 p++;
               }
               if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                {
+                  status=SetImageProgress(image,SaveImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
 #if defined(MAGICKCORE_ZLIB_DELEGATE)
             if (compression == ZipCompression)
@@ -1516,14 +1512,11 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
                 p++;
               }
               if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                {
+                  status=SetImageProgress(image,SaveImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
             Ascii85Flush(image);
             break;
@@ -1583,14 +1576,11 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
                 p++;
               }
               if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                {
+                  status=SetImageProgress(image,SaveImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
 #if defined(MAGICKCORE_ZLIB_DELEGATE)
             if (compression == ZipCompression)
@@ -1632,14 +1622,11 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
                 p++;
               }
               if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                {
+                  status=SetImageProgress(image,SaveImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
             Ascii85Flush(image);
             break;
@@ -1678,11 +1665,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                   *q++=(unsigned char) indexes[x];
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
+                    status=SetImageProgress(image,SaveImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -1720,11 +1704,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                   Ascii85Encode(image,(unsigned char) indexes[x]);
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
+                    status=SetImageProgress(image,SaveImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -2358,14 +2339,10 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    scene++;
+    status=SetImageProgress(image,SaveImagesTag,scene++,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
   } while (image_info->adjoin != MagickFalse);
   /*
     Write Metadata object.
