@@ -1241,15 +1241,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                   if (p < pixels)
                     break;
                 }
-              if (destination.bottom == (long) image->rows)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,tile_image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(LoadImageTag,y,
-                      tile_image->rows,image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+              status=SetImageProgress(image,LoadImageTag,y,tile_image->rows);
+              if (status == MagickFalse)
+                break;
             }
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             if (jpeg == MagickFalse)
@@ -1258,13 +1252,6 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 (void) CompositeImage(image,CopyCompositeOp,tile_image,
                   destination.left,destination.top);
             tile_image=DestroyImage(tile_image);
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
-              {
-                status=image->progress_monitor(LoadImageTag,destination.bottom,
-                  image->rows,image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
             break;
           }
           case 0xa1:
@@ -1654,7 +1641,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   y_resolution=image->y_resolution != 0.0 ? image->y_resolution :
     DefaultResolution;
   storage_class=image->storage_class;
-  if (image->compression == JPEGCompression)
+  if (image_info->compression == JPEGCompression)
     storage_class=DirectClass;
   if ((storage_class == DirectClass) || (image->matte != MagickFalse))
     {
@@ -1738,7 +1725,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   (void) WriteBlobMSBShort(image,(unsigned short) crop_rectangle.left);
   (void) WriteBlobMSBShort(image,(unsigned short) crop_rectangle.bottom);
   (void) WriteBlobMSBShort(image,(unsigned short) crop_rectangle.right);
-  if (image->compression == JPEGCompression)
+  if (image_info->compression == JPEGCompression)
     {
       Image
         *jpeg_image;
@@ -1912,7 +1899,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
         }
     }
   else
-    if (image->compression == JPEGCompression)
+    if (image_info->compression == JPEGCompression)
       {
         (void) ResetMagickMemory(scanline,0,row_bytes);
         for (y=0; y < (long) image->rows; y++)
