@@ -1945,11 +1945,10 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene,
+    status=SetImageProgress(image,SaveImagesTag,scene++,
       GetImageListLength(image));
     if (status == MagickFalse)
       break;
-    scene++;
   } while (image_info->adjoin != MagickFalse);
   (void) CloseBlob(image);
   return(MagickTrue);
