@@ -1677,14 +1677,11 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                 p++;
               }
               if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                {
+                  status=SetImageProgress(image,SaveImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
             if (q != pixels)
               {
@@ -1749,14 +1746,11 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                     }
                 };
               if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                {
+                  status=SetImageProgress(image,SaveImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
             if (q != pixels)
               {
@@ -1824,11 +1818,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                     q=pixels;
                   }
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
+                    status=SetImageProgress(image,SaveImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -1877,11 +1868,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                   p++;
                 }
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
+                    status=SetImageProgress(image,SaveImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -1962,14 +1950,10 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                   p++;
                 }
                 q=PopHexPixel(hex_digits,index,q);
-                q=PopHexPixel(hex_digits,MagickMin(length,0xff),
-                  q);
+                q=PopHexPixel(hex_digits,MagickMin(length,0xff),q);
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
+                    status=SetImageProgress(image,SaveImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -2007,11 +1991,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                   p++;
                 }
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
                   {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
+                    status=SetImageProgress(image,SaveImageTag,y,image->rows);
                     if (status == MagickFalse)
                       break;
                   }
@@ -2032,14 +2013,10 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    scene++;
+    status=SetImageProgress(image,SaveImagesTag,scene++,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
   } while (image_info->adjoin != MagickFalse);
   (void) WriteBlobString(image,"%%Trailer\n");
   if (page > 2)
