@@ -247,14 +247,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
             }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -317,14 +314,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
             }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -386,10 +380,9 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
             }
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,100,400,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,1,5);
             if (status == MagickFalse)
               break;
           }
@@ -438,10 +431,9 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
            }
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,200,400,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,2,5);
             if (status == MagickFalse)
               break;
           }
@@ -490,10 +482,9 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
             }
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,300,400,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,3,5);
             if (status == MagickFalse)
               break;
           }
@@ -545,11 +536,16 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     break;
                 }
             }
+            if (image->previous == (Image *) NULL)
+              {
+                status=SetImageProgress(image,LoadImageTag,4,5);
+                if (status == MagickFalse)
+                  break;
+              }
           }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,400,400,
-              image->client_data);
+            status=SetImageProgress(image,LoadImageTag,5,5);
             if (status == MagickFalse)
               break;
           }
@@ -575,13 +571,10 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-              GetBlobSize(image),image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+          GetBlobSize(image));
+        if (status == MagickFalse)
+          break;
       }
   } while (count == (ssize_t) length);
   InheritException(exception,&image->exception);
@@ -785,14 +778,11 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -834,11 +824,9 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
               if (count != (ssize_t) length)
                 break;
             }
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
+          if (image->previous == (Image *) NULL)
             {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
               if (status == MagickFalse)
                 break;
             }
@@ -869,10 +857,9 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,100,400,
-              image->client_data);
+            status=SetImageProgress(image,SaveImageTag,1,5);
             if (status == MagickFalse)
               break;
           }
@@ -895,10 +882,9 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
         }
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,200,400,
-              image->client_data);
+            status=SetImageProgress(image,SaveImageTag,2,5);
             if (status == MagickFalse)
               break;
           }
@@ -921,15 +907,14 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
         }
+        if (image->previous == (Image *) NULL)
+          {
+            status=SetImageProgress(image,SaveImageTag,3,5);
+            if (status == MagickFalse)
+              break;
+          }
         if (quantum_type == RGBAQuantum)
           {
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
-              {
-                status=image->progress_monitor(LoadImageTag,300,400,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
             if (image_info->interlace == PartitionInterlace)
               {
                 (void) CloseBlob(image);
@@ -954,10 +939,9 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           }
         if (quantum_type == RGBOQuantum)
           {
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
+            if (image->previous == (Image *) NULL)
               {
-                status=image->progress_monitor(LoadImageTag,300,400,
-                  image->client_data);
+                status=SetImageProgress(image,SaveImageTag,4,5);
                 if (status == MagickFalse)
                   break;
               }
@@ -986,10 +970,9 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
         if (image_info->interlace == PartitionInterlace)
           (void) CopyMagickString(image->filename,image_info->filename,
             MaxTextExtent);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+        if (image->previous == (Image *) NULL)
           {
-            status=image->progress_monitor(LoadImageTag,400,400,
-              image->client_data);
+            status=SetImageProgress(image,SaveImageTag,5,5);
             if (status == MagickFalse)
               break;
           }
@@ -1000,14 +983,10 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    scene++;
+    status=SetImageProgress(image,SaveImagesTag,scene++,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
   } while (image_info->adjoin != MagickFalse);
   (void) CloseBlob(image);
   return(MagickTrue);
