@@ -199,14 +199,9 @@ static Image *ReadSTEGANOImage(const ImageInfo *image_info,
           j++;
       }
     }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(i,MAGICKCORE_QUANTUM_DEPTH) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImagesTag,i,MAGICKCORE_QUANTUM_DEPTH,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,LoadImagesTag,i,MAGICKCORE_QUANTUM_DEPTH);
+    if (status == MagickFalse)
+      break;
   }
   watermark=DestroyImage(watermark);
   (void) SyncImage(image);
