@@ -2035,7 +2035,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       (void) TIFFSetField(tiff,TIFFTAG_SUBFILETYPE,FILETYPE_REDUCEDIMAGE);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGELENGTH,(uint32) image->rows);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGEWIDTH,(uint32) image->columns);
-    compression=image->compression;
+    compression=image_info->compression;
     switch (compression)
     {
       case FaxCompression:
@@ -2665,6 +2665,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
         break;
       }
     }
+    quantum_info=DestroyQuantumInfo(quantum_info);
     DestroyTIFFInfo(&tiff_info);
     if (image_info->verbose == MagickTrue)
       TIFFPrintDirectory(tiff,stdout,MagickFalse);
@@ -2675,12 +2676,10 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
     image=SyncNextImageInList(image);
     if (image == (Image *) NULL)
       break;
-    status=SetImageProgress(image,SaveImagesTag,scene,
+    status=SetImageProgress(image,SaveImagesTag,scene++,
       GetImageListLength(image));
     if (status == MagickFalse)
       break;
-    scene++;
-    quantum_info=DestroyQuantumInfo(quantum_info);
   } while (image_info->adjoin != MagickFalse);
   TIFFClose(tiff);
   return(MagickTrue);
