@@ -277,14 +277,11 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
     (void) ConcatenateString(&draw_info->text,"\n");
     offset+=(long) (metrics.ascent-metrics.descent);
     if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(offset,image->rows) != MagickFalse))
-        {
-          status=image->progress_monitor(LoadImageTag,offset,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
+      {
+        status=SetImageProgress(image,LoadImageTag,offset,image->rows);
+        if (status == MagickFalse)
+          break;
+      }
     p=ReadBlobString(image,text);
     if ((offset < (long) image->rows) && (p != (char *) NULL))
       continue;
@@ -318,13 +315,10 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
     image=SyncNextImageInList(image);
     (void) CopyMagickString(image->filename,filename,MaxTextExtent);
     (void) SetImageBackgroundColor(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-          GetBlobSize(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+      GetBlobSize(image));
+    if (status == MagickFalse)
+      break;
   }
   if (texture != (Image *) NULL)
     {
@@ -677,15 +671,9 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
       (void) WriteBlobString(image,"\n");
       p++;
     }
-    if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
-        {
-          status=image->progress_monitor(SaveImageTag,y,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
+    status=SetImageProgress(image,SaveImageTag,y,image->rows);
+    if (status == MagickFalse)
+      break;
   }
   (void) CloseBlob(image);
   return(MagickTrue);
