@@ -190,13 +190,9 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
         "thumbnail geometry: %ldx%ld",next_image->columns,next_image->rows);
     AppendImageToList(&images,next_image);
-    if (images->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=images->progress_monitor(LoadImagesTag,i,(MagickSizeType)
-          number_files,images->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,LoadImagesTag,i,number_files);
+    if (status == MagickFalse)
+      break;
   }
   read_info=DestroyImageInfo(read_info);
   filelist=(char **) RelinquishMagickMemory(filelist);
