@@ -137,7 +137,6 @@ static MagickBooleanType
 %    %o   output image filename.
 %    %p   page number of the image.
 %    %q   image depth (8 or 16).
-%    %p   page number of the image.
 %    %q   image depth (8 or 16).
 %    %s   image scene number.
 %    %t   image filename without any extension.
@@ -829,11 +828,17 @@ MagickExport long FormatMagickCaption(Image *image,DrawInfo *draw_info,
 %
 %    character width
 %    character height
-%    ascent
-%    descent
+%    ascender
+%    descender
 %    text width
 %    text height
 %    maximum horizontal advance
+%    bounds: x1
+%    bounds: y1
+%    bounds: x2
+%    bounds: y2
+%    origin: x
+%    origin: y
 %    underline position
 %    underline thickness
 %
@@ -938,11 +943,17 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
 %
 %    character width
 %    character height
-%    ascent
-%    descent
+%    ascender
+%    descender
 %    text width
 %    text height
 %    maximum horizontal advance
+%    bounds: x1
+%    bounds: y1
+%    bounds: x2
+%    bounds: y2
+%    origin: x
+%    origin: y
 %    underline position
 %    underline thickness
 %
@@ -985,6 +996,16 @@ MagickExport MagickBooleanType GetTypeMetrics(Image *image,
   offset.x=0.0;
   offset.y=0.0;
   status=RenderType(image,annotate_info,&offset,metrics);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(AnnotateEvent,GetMagickModule(),"Metrics: text: %s; "
+      "width: %g; height: %g; ascent: %g; descent: %g; max advance: %g; "
+      "bounds: %g,%g  %g,%g; origin: %g,%g; pixels per em: %g,%g; "
+      "underline position: %g; underline thickness: %g",annotate_info->text,
+      metrics->width,metrics->height,metrics->ascent,metrics->descent,
+      metrics->max_advance,metrics->bounds.x1,metrics->bounds.y1,
+      metrics->bounds.x2,metrics->bounds.y2,metrics->origin.x,metrics->origin.y,
+      metrics->pixels_per_em.x,metrics->pixels_per_em.y,
+      metrics->underline_position,metrics->underline_thickness);
   annotate_info=DestroyDrawInfo(annotate_info);
   return(status);
 }
