@@ -117,6 +117,8 @@ MagickExport ViewInfo *AcquireCacheView(const Image *image)
   cache_view->virtual_pixel_method=GetImageVirtualPixelMethod(image);
   cache_view->debug=IsEventLogging();
   cache_view->signature=MagickSignature;
+  if (cache_view->id == 0)
+    ThrowFatalException(CacheFatalError,"UnableToAcquireCacheView");
   return(cache_view);
 }
 
