@@ -148,11 +148,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   long
     y;
 
-  IndexPacket
-    *indexes;
-
   MagickBooleanType
-    proceed;
+    proceed,
+    status;
 
   PrimaryInfo
     primary_info,
@@ -161,11 +159,10 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     *z_map;
 
   register long
-    i,
-    x;
+    i;
 
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -189,7 +186,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     }
   }
   image->colorspace=colorspace;
-  (void) SetImagePixels(image,0,0,image->columns,1);
+  if (SyncImagePixelCache(image) == MagickFalse)
+    return(MagickFalse);
+  status=MagickTrue;
   switch (colorspace)
   {
     case CMYColorspace:
@@ -204,34 +203,43 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
-        indexes=GetIndexes(image);
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=RoundToQuantum((MagickRealType) QuantumRange-q->red);
-          q->green=RoundToQuantum((MagickRealType) QuantumRange-q->green);
-          q->blue=RoundToQuantum((MagickRealType) QuantumRange-q->blue);
+          q->red=RoundToQuantum((MagickRealType) (QuantumRange-q->red));
+          q->green=RoundToQuantum((MagickRealType) (QuantumRange-q->green));
+          q->blue=RoundToQuantum((MagickRealType) (QuantumRange-q->blue));
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->type=image->matte == MagickFalse ? ColorSeparationType :
         ColorSeparationMatteType;
-      return(MagickTrue);
+      return(status);
     }
     case CMYKColorspace:
     {
-      MagickBooleanType
-        status;
-
-      ViewInfo
-        **image_view;
-
       /*
         Convert RGB to CMYK colorspace.
       */
@@ -242,7 +250,6 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      status=MagickTrue;
       image_view=AcquireCacheViewThreadSet(image);
       #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
@@ -260,8 +267,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         register PixelPacket
           *q;
 
-    if (status == MagickFalse)
-      continue;
+        if (status == MagickFalse)
+          continue;
         id=GetCacheViewThreadId();
         q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
@@ -288,11 +295,6 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     }
     case HSBColorspace:
     {
-      double
-        brightness,
-        hue,
-        saturation;
-
       /*
         Transform image from RGB to HSB.
       */
@@ -303,14 +305,34 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      hue=0.0;
-      saturation=0.0;
-      brightness=0.0;
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          brightness,
+          hue,
+          saturation;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
+        hue=0.0;
+        saturation=0.0;
+        brightness=0.0;
         for (x=0; x < (long) image->columns; x++)
         {
           ConvertRGBToHSB(q->red,q->green,q->blue,&hue,&saturation,&brightness);
@@ -319,18 +341,14 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           q->blue=RoundToQuantum((MagickRealType) QuantumRange*brightness);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
-      return(MagickTrue);
+      image_view=DestroyCacheViewThreadSet(image_view);
+      return(status);
     }
     case HSLColorspace:
     {
-      double
-        hue,
-        lightness,
-        saturation;
-
       /*
         Transform image from RGB to HSL.
       */
@@ -341,14 +359,34 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      hue=0.0;
-      saturation=0.0;
-      lightness=0.0;
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          hue,
+          lightness,
+          saturation;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
+        hue=0.0;
+        saturation=0.0;
+        lightness=0.0;
         for (x=0; x < (long) image->columns; x++)
         {
           ConvertRGBToHSL(q->red,q->green,q->blue,&hue,&saturation,&lightness);
@@ -357,18 +395,14 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           q->blue=RoundToQuantum((MagickRealType) QuantumRange*lightness);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
-      return(MagickTrue);
+      image_view=DestroyCacheViewThreadSet(image_view);
+      return(status);
     }
     case HWBColorspace:
     {
-      double
-        blackness,
-        hue,
-        whiteness;
-
       /*
         Transform image from RGB to HWB.
       */
@@ -379,14 +413,34 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      hue=0.0;
-      whiteness=0.0;
-      blackness=0.0;
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          blackness,
+          hue,
+          whiteness;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
+        hue=0.0;
+        whiteness=0.0;
+        blackness=0.0;
         for (x=0; x < (long) image->columns; x++)
         {
           ConvertRGBToHWB(q->red,q->green,q->blue,&hue,&whiteness,&blackness);
@@ -395,21 +449,14 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           q->blue=RoundToQuantum((MagickRealType) QuantumRange*blackness);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
-      return(MagickTrue);
+      image_view=DestroyCacheViewThreadSet(image_view);
+      return(status);
     }
     case LabColorspace:
     {
-      double
-        a,
-        b,
-        L,
-        X,
-        Y,
-        Z;
-
       /*
         Transform image from RGB to Lab.
       */
@@ -420,17 +467,40 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      L=0.0;
-      a=0.0;
-      b=0.0;
-      X=0.0;
-      Y=0.0;
-      Z=0.0;
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          a,
+          b,
+          L,
+          X,
+          Y,
+          Z;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
+        L=0.0;
+        a=0.0;
+        b=0.0;
+        X=0.0;
+        Y=0.0;
+        Z=0.0;
         for (x=0; x < (long) image->columns; x++)
         {
           ConvertRGBToXYZ(q->red,q->green,q->blue,&X,&Y,&Z);
@@ -440,10 +510,11 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           q->blue=RoundToQuantum((MagickRealType) QuantumRange*b);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
-      return(MagickTrue);
+      image_view=DestroyCacheViewThreadSet(image_view);
+      return(status);
     }
     case LogColorspace:
     {
@@ -491,11 +562,26 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         logmap[i]=ScaleMapToQuantum((MagickRealType) (MaxMap*(reference_white+
           log10(black+((double) i/MaxMap)*(1.0-black))/((gamma/density)*
           0.002/0.6))/1024.0+0.5));
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=(long) image->columns; x != 0; x--)
         {
           q->red=logmap[ScaleQuantumToMap(q->red)];
@@ -503,11 +589,12 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           q->blue=logmap[ScaleQuantumToMap(q->blue)];
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       logmap=(Quantum *) RelinquishMagickMemory(logmap);
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      return(status);
     }
     default:
       break;
@@ -854,17 +941,33 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     case DirectClass:
     default:
     {
-      MagickPixelPacket
-        pixel;
-
       /*
         Convert DirectClass image.
       */
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        MagickPixelPacket
+          pixel;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
+        GetMagickPixelPacket(image,&pixel);
         for (x=0; x < (long) image->columns; x++)
         {
           pixel.red=x_map[ScaleQuantumToMap(q->red)].x+
@@ -881,24 +984,28 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           q->blue=ScaleMapToQuantum(pixel.blue);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
         proceed=SetImageProgress(image,RGBTransformImageTag,y,image->rows);
         if (proceed == MagickFalse)
-          break;
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       break;
     }
     case PseudoClass:
     {
-      MagickPixelPacket
-        pixel;
-
       /*
         Convert PseudoClass image.
       */
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (i=0; i < (long) image->colors; i++)
       {
+        MagickPixelPacket
+          pixel;
+
+        GetMagickPixelPacket(image,&pixel);
         pixel.red=x_map[ScaleQuantumToMap(image->colormap[i].red)].x+
           y_map[ScaleQuantumToMap(image->colormap[i].green)].x+
           z_map[ScaleQuantumToMap(image->colormap[i].blue)].x+primary_info.x;
@@ -912,6 +1019,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         image->colormap[i].green=ScaleMapToQuantum(pixel.green);
         image->colormap[i].blue=ScaleMapToQuantum(pixel.blue);
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       (void) SyncImage(image);
       break;
     }
@@ -922,7 +1030,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   z_map=(PrimaryInfo *) RelinquishMagickMemory(z_map);
   y_map=(PrimaryInfo *) RelinquishMagickMemory(y_map);
   x_map=(PrimaryInfo *) RelinquishMagickMemory(x_map);
-  return(MagickTrue);
+  return(status);
 }
 
 /*
@@ -963,6 +1071,8 @@ MagickExport MagickBooleanType SetImageColorspace(Image *image,
   if (colorspace == UndefinedColorspace)
     {
       image->colorspace=UndefinedColorspace;
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
       return(MagickTrue);
     }
   if (image->colorspace == colorspace)
@@ -1125,24 +1235,19 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     y;
 
   MagickBooleanType
-    proceed;
-
-  MagickPixelPacket
-    pixel;
+    proceed,
+    status;
 
   PrimaryInfo
     *y_map,
     *x_map,
     *z_map;
 
-  register long
-    x;
-
   register long
     i;
 
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -1160,6 +1265,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     default:
       break;
   }
+  status=MagickTrue;
   switch (colorspace)
   {
     case CMYColorspace:
@@ -1174,32 +1280,44 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=RoundToQuantum((MagickRealType) QuantumRange-q->red);
-          q->green=RoundToQuantum((MagickRealType) QuantumRange-q->green);
-          q->blue=RoundToQuantum((MagickRealType) QuantumRange-q->blue);
+          q->red=RoundToQuantum((MagickRealType) (QuantumRange-q->red));
+          q->green=RoundToQuantum((MagickRealType) (QuantumRange-q->green));
+          q->blue=RoundToQuantum((MagickRealType) (QuantumRange-q->blue));
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->colorspace=RGBColorspace;
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
+      return(status);
     }
     case CMYKColorspace:
     {
-      IndexPacket
-        *indexes;
-
-      MagickPixelPacket
-        pixel;
-
       /*
         Transform image from CMYK to RGB.
       */
@@ -1210,13 +1328,34 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      GetMagickPixelPacket(image,&pixel);
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        MagickPixelPacket
+          pixel;
+
+        register IndexPacket
+          *indexes;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         indexes=GetIndexes(image);
+        GetMagickPixelPacket(image,&pixel);
         for (x=0; x < (long) image->columns; x++)
         {
           SetMagickPixelPacket(image,q,indexes+x,&pixel);
@@ -1224,20 +1363,17 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           SetPixelPacket(image,&pixel,q,indexes+x);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->colorspace=RGBColorspace;
-      (void) SetImagePixels(image,0,0,image->columns,1);
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
+      return(status);
     }
     case HSBColorspace:
     {
-      double
-        brightness,
-        hue,
-        saturation;
-
       /*
         Transform image from HSB to RGB.
       */
@@ -1248,11 +1384,31 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          brightness,
+          hue,
+          saturation;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=0; x < (long) image->columns; x++)
         {
           hue=(double) (QuantumScale*q->red);
@@ -1261,19 +1417,17 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           ConvertHSBToRGB(hue,saturation,brightness,&q->red,&q->green,&q->blue);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->colorspace=RGBColorspace;
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
+      return(status);
     }
     case HSLColorspace:
     {
-      double
-        hue,
-        lightness,
-        saturation;
-
       /*
         Transform image from HSL to RGB.
       */
@@ -1284,11 +1438,31 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          hue,
+          lightness,
+          saturation;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=0; x < (long) image->columns; x++)
         {
           hue=(double) (QuantumScale*q->red);
@@ -1297,19 +1471,17 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           ConvertHSLToRGB(hue,saturation,lightness,&q->red,&q->green,&q->blue);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->colorspace=RGBColorspace;
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
+      return(status);
     }
     case HWBColorspace:
     {
-      double
-        blackness,
-        hue,
-        whiteness;
-
       /*
         Transform image from HWB to RGB.
       */
@@ -1320,11 +1492,31 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          blackness,
+          hue,
+          whiteness;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=0; x < (long) image->columns; x++)
         {
           hue=(double) (QuantumScale*q->red);
@@ -1333,22 +1525,17 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           ConvertHWBToRGB(hue,whiteness,blackness,&q->red,&q->green,&q->blue);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->colorspace=RGBColorspace;
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
+      return(status);
     }
     case LabColorspace:
     {
-      double
-        a,
-        b,
-        L,
-        X,
-        Y,
-        Z;
-
       /*
         Transform image from Lab to RGB.
       */
@@ -1359,17 +1546,37 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      L=0.0;
-      a=0.0;
-      b=0.0;
-      X=0.0;
-      Y=0.0;
-      Z=0.0;
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        double
+          a,
+          b,
+          L,
+          X,
+          Y,
+          Z;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
+        X=0.0;
+        Y=0.0;
+        Z=0.0;
         for (x=0; x < (long) image->columns; x++)
         {
           L=QuantumScale*q->red;
@@ -1379,11 +1586,14 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           ConvertXYZToRGB(X,Y,Z,&q->red,&q->green,&q->blue);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->colorspace=RGBColorspace;
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
+      return(status);
     }
     case LogColorspace:
     {
@@ -1433,11 +1643,26 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         logmap[i]=(Quantum) QuantumRange;
       if (SetImageStorageClass(image,DirectClass) == MagickFalse)
         return(MagickFalse);
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=(long) image->columns; x != 0; x--)
         {
           q->red=logmap[ScaleQuantumToMap(q->red)];
@@ -1445,12 +1670,15 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           q->blue=logmap[ScaleQuantumToMap(q->blue)];
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       logmap=(Quantum *) RelinquishMagickMemory(logmap);
       image->colorspace=RGBColorspace;
-      return(y == (long) image->rows ? MagickTrue : MagickFalse);
+      if (SyncImagePixelCache(image) == MagickFalse)
+        return(MagickFalse);
+      return(status);
     }
     default:
       break;
@@ -1466,8 +1694,16 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     sizeof(*z_map));
   if ((x_map == (PrimaryInfo *) NULL) || (y_map == (PrimaryInfo *) NULL) ||
       (z_map == (PrimaryInfo *) NULL))
-    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-      image->filename);
+    {
+      if (z_map != (PrimaryInfo *) NULL)
+        z_map=(PrimaryInfo *) RelinquishMagickMemory(z_map);
+      if (y_map != (PrimaryInfo *) NULL)
+        y_map=(PrimaryInfo *) RelinquishMagickMemory(y_map);
+      if (x_map != (PrimaryInfo *) NULL)
+        x_map=(PrimaryInfo *) RelinquishMagickMemory(x_map);
+      ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
+        image->filename);
+    }
   switch (colorspace)
   {
     case OHTAColorspace:
@@ -1724,11 +1960,30 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       /*
         Convert DirectClass image.
       */
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        MagickPixelPacket
+          pixel;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+        if (status == MagickFalse)
+          continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
+        GetMagickPixelPacket(image,&pixel);
         for (x=0; x < (long) image->columns; x++)
         {
           pixel.red=x_map[ScaleQuantumToMap(q->red)].x+
@@ -1784,12 +2039,13 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             pixel.blue);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
         proceed=SetImageProgress(image,TransformRGBImageTag,y,image->rows);
         if (proceed == MagickFalse)
-          break;
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       break;
     }
     case PseudoClass:
@@ -1797,8 +2053,14 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       /*
         Convert PseudoClass image.
       */
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (i=0; i < (long) image->colors; i++)
       {
+        MagickPixelPacket
+          pixel;
+
+        GetMagickPixelPacket(image,&pixel);
         pixel.red=x_map[ScaleQuantumToMap(image->colormap[i].red)].x+
           y_map[ScaleQuantumToMap(image->colormap[i].green)].x+
           z_map[ScaleQuantumToMap(image->colormap[i].blue)].x;
@@ -1852,16 +2114,19 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           }
         }
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       (void) SyncImage(image);
       break;
     }
   }
-  image->colorspace=RGBColorspace;
   /*
     Relinquish resources.
   */
   z_map=(PrimaryInfo *) RelinquishMagickMemory(z_map);
   y_map=(PrimaryInfo *) RelinquishMagickMemory(y_map);
   x_map=(PrimaryInfo *) RelinquishMagickMemory(x_map);
+  image->colorspace=RGBColorspace;
+  if (SyncImagePixelCache(image) == MagickFalse)
+    return(MagickFalse);
   return(MagickTrue);
 }
