@@ -997,10 +997,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     *value;
 
   double
-    brightness,
-    hue,
-    sans,
-    saturation;
+    sans;
 
   GeometryInfo
     geometry_info;
@@ -1009,6 +1006,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     *displace_image;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -1279,9 +1277,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     Composite image.
   */
   status=MagickTrue;
-  hue=0.0;
-  saturation=0.0;
-  brightness=0.0;
+  progress=0;
   midpoint=((MagickRealType) QuantumRange+1.0)/2;
   image_view=AcquireCacheViewThreadSet(image);
   composite_view=AcquireCacheViewThreadSet(composite_image);
@@ -1291,6 +1287,11 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     const PixelPacket
       *pixels;
 
+    double
+      brightness,
+      hue,
+      saturation;
+
     MagickPixelPacket
       composite,
       destination,
@@ -1350,6 +1351,9 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     composite_indexes=AcquireCacheViewIndexes(composite_view[id]);
     GetMagickPixelPacket(composite_image,&source);
     GetMagickPixelPacket(image,&destination);
+    hue=0.0;
+    saturation=0.0;
+    brightness=0.0;
     for (x=0; x < (long) image->columns; x++)
     {
       if (modify_outside_overlay == MagickFalse)
@@ -1816,8 +1820,17 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,CompositeImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,CompositeImageTag,progress++,
+          image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   composite_view=DestroyCacheViewThreadSet(composite_view);
   image_view=DestroyCacheViewThreadSet(image_view);
