@@ -64,10 +64,13 @@ typedef enum
 } SparseColorInterpolateMethod;
 
 extern MagickExport Image
-  *DistortImage(const Image *image,const DistortImageMethod,const unsigned long,
+  *DistortImage(const Image *,const DistortImageMethod,const unsigned long,
     const double *,MagickBooleanType,ExceptionInfo *exception),
-  *SparseColorInterpolate(const Image *image,const SparseColorInterpolateMethod,
-    const unsigned long,const double *,ExceptionInfo *exception);
+  *SparseColorInterpolate(const Image *,const SparseColorInterpolateMethod,
+    const unsigned long,const double *,const ChannelType,ExceptionInfo *),
+  *SparseColorStringArg(const Image *, SparseColorInterpolateMethod,
+    const char *,const MagickBooleanType,ChannelType,ExceptionInfo *);
+
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
