@@ -1536,7 +1536,7 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
         indexes[x]=RoundToQuantum(gamma_map[ScaleQuantumToMap(indexes[x])]);
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
+    if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
       {
@@ -1963,9 +1963,8 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
 %  The format of the LevelImageColors method is:
 %
 %  MagickBooleanType LevelImageColors(Image *image,const ChannelType channel,
-%         const MagickPixelPacket *black_color,
-%         const MagickPixelPacket *white_color,
-%         const MagickBooleanType invert)
+%    const MagickPixelPacket *black_color,const MagickPixelPacket *white_color,
+%    const MagickBooleanType invert)
 %
 %  A description of each parameter follows:
 %
@@ -1981,8 +1980,8 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
 %
 */
 MagickBooleanType LevelImageColors(Image *image,const ChannelType channel,
-     const MagickPixelPacket *black_color, const MagickPixelPacket
-     *white_color, const MagickBooleanType invert)
+  const MagickPixelPacket *black_color,const MagickPixelPacket *white_color,
+  const MagickBooleanType invert)
 {
 #define LevelColorImageTag  "LevelColor/Image"
 
@@ -2500,8 +2499,8 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
         register PixelPacket
           *q;
 
-    if (status == MagickFalse)
-      continue;
+        if (status == MagickFalse)
+          continue;
         id=GetCacheViewThreadId();
         q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
