@@ -461,13 +461,15 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         }
       }
       if (image->matte != MagickFalse)
-        (void) fprintf(file,IdentifyFormat,"alpha",(Quantum)
-          (channel_statistics[AlphaChannel].minima/scale),(double)
-          channel_statistics[AlphaChannel].minima/(double) QuantumRange,
-          (Quantum) (channel_statistics[AlphaChannel].maxima/scale),(double)
-          channel_statistics[AlphaChannel].maxima/(double) QuantumRange,
-          channel_statistics[AlphaChannel].mean/(double) scale,
-          channel_statistics[AlphaChannel].mean/(double) QuantumRange,
+        (void) fprintf(file,IdentifyFormat,"alpha",(Quantum) ((QuantumRange-
+          channel_statistics[AlphaChannel].minima)/scale),(double)
+          (QuantumRange-channel_statistics[AlphaChannel].minima)/(double)
+          QuantumRange,(Quantum) ((QuantumRange-
+          channel_statistics[AlphaChannel].maxima)/scale),(double)
+          (QuantumRange-channel_statistics[AlphaChannel].maxima)/(double)
+          QuantumRange,(QuantumRange-channel_statistics[AlphaChannel].mean)/
+          (double) scale,(QuantumRange-channel_statistics[AlphaChannel].mean)/
+          (double) QuantumRange,
           channel_statistics[AlphaChannel].standard_deviation/(double) scale,
           channel_statistics[AlphaChannel].standard_deviation/(double)
           QuantumRange);
