@@ -51,6 +51,7 @@
 #include "magick/list.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/pixel-private.h"
 #include "magick/property.h"
 #include "magick/profile.h"
@@ -1818,7 +1819,7 @@ MagickExport Image *MergeImageLayers(const Image *image,
     *canvas;
 
   MagickBooleanType
-    status;
+    proceed;
 
   MagickOffsetType
     scene;
@@ -1925,16 +1926,11 @@ MagickExport Image *MergeImageLayers(const Image *image,
   number_images=GetImageListLength(image);
   for (scene=0; scene < (long) number_images; scene++)
   {
-    (void) CompositeImage(canvas,image->compose,image,
-         image->page.x-canvas->page.x, image->page.y-canvas->page.y );
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(scene,number_images) != MagickFalse))
-      {
-        status=image->progress_monitor(MergeLayersTag,scene,number_images,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    (void) CompositeImage(canvas,image->compose,image,image->page.x-
+      canvas->page.x,image->page.y-canvas->page.y);
+    proceed=SetImageProgress(image,MergeLayersTag,scene,number_images);
+    if (proceed == MagickFalse)
+      break;
     image=GetNextImageInList(image);
   }
   return(canvas);
