@@ -17,7 +17,7 @@
 %                                September 2002                               %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -56,7 +56,7 @@
 #include "magick/utility.h"
 #include "magick/version.h"
 #include "magick/xml-tree.h"
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
 #include <pthread.h>
 #endif
 #if defined(__WINDOWS__)
@@ -278,7 +278,7 @@ MagickExport void DestroyLogList(void)
     log_list=DestroyLinkedList(log_list,DestroyLogElement);
   instantiate_log=MagickFalse;
   RelinquishSemaphoreInfo(log_semaphore);
-  log_semaphore=DestroySemaphoreInfo(log_semaphore);
+  DestroySemaphoreInfo(&log_semaphore);
 }
 
 /*
@@ -301,7 +301,7 @@ MagickExport void DestroyLogList(void)
 %
 %  A description of each parameter follows:
 %
-%    o name: The log name.
+%    o name: the log name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -410,8 +410,8 @@ MagickExport const LogInfo **GetLogInfoList(const char *pattern,
   p=GetLogInfo("*",exception);
   if (p == (const LogInfo *) NULL)
     return((const LogInfo **) NULL);
-  preferences=(const LogInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(log_list)+1)*sizeof(*preferences));
+  preferences=(const LogInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(log_list)+1UL,sizeof(*preferences));
   if (preferences == (const LogInfo **) NULL)
     return((const LogInfo **) NULL);
   /*
@@ -503,8 +503,8 @@ MagickExport char **GetLogList(const char *pattern,
   p=GetLogInfo("*",exception);
   if (p == (const LogInfo *) NULL)
     return((char **) NULL);
-  preferences=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(log_list)+1)*sizeof(*preferences));
+  preferences=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(log_list)+1UL,sizeof(*preferences));
   if (preferences == (char **) NULL)
     return((char **) NULL);
   /*
@@ -730,21 +730,21 @@ MagickExport MagickBooleanType ListLogInfo(FILE *file,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o type: The event type.
+%    o type: the event type.
 %
-%    o filename: The source module filename.
+%    o filename: the source module filename.
 %
-%    o function: The function name.
+%    o function: the function name.
 %
-%    o line: The line number of the source module.
+%    o line: the line number of the source module.
 %
-%    o format: The output format.
+%    o format: the output format.
 %
 */
 
 static unsigned long GetLogThreadId(void)
 {
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   return((unsigned long) pthread_self());
 #endif
 #if defined(__WINDOWS__)
@@ -779,9 +779,6 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
   size_t
     extent;
 
-  struct tm
-    *time_meridian;
-
   time_t
     seconds;
 
@@ -789,7 +786,6 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
   log_info=(LogInfo *) GetLogInfo("*",exception);
   exception=DestroyExceptionInfo(exception);
   seconds=time((time_t *) NULL);
-  time_meridian=localtime(&seconds);
   elapsed_time=GetElapsedTime(&log_info->timer);
   user_time=GetUserTime(&log_info->timer);
   text=AcquireString(event);
@@ -832,7 +828,7 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
     if ((size_t) (q-text+MaxTextExtent) >= extent)
       {
         extent+=MaxTextExtent;
-        text=(char *) ResizeMagickMemory(text,(extent+MaxTextExtent)*
+        text=(char *) ResizeQuantumMemory(text,extent+MaxTextExtent,
           sizeof(*text));
         if (text == (char *) NULL)
           return((char *) NULL);
@@ -1005,7 +1001,7 @@ static char *TranslateFilename(const LogInfo *log_info)
     if ((size_t) (q-filename+MaxTextExtent) >= extent)
       {
         extent+=MaxTextExtent;
-        filename=(char *) ResizeMagickMemory(filename,(extent+MaxTextExtent)*
+        filename=(char *) ResizeQuantumMemory(filename,extent+MaxTextExtent,
           sizeof(*filename));
         if (filename == (char *) NULL)
           return((char *) NULL);
@@ -1110,12 +1106,12 @@ MagickBooleanType LogMagickEventList(const LogEventType type,const char *module,
       return(MagickTrue);
     }
   domain=MagickOptionToMnemonic(MagickLogEventOptions,type);
-#if defined(HAVE_VSNPRINTF)
+#if defined(MAGICKCORE_HAVE_VSNPRINTF)
   n=vsnprintf(event,MaxTextExtent,format,operands);
 #else
   n=vsprintf(event,format,operands);
 #endif
-  if  (n < 0)
+  if (n < 0)
     event[MaxTextExtent-1]='\0';
   text=TranslateEvent(type,module,function,line,domain,event);
   if (text == (char *) NULL)
@@ -1353,8 +1349,7 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
         */
         log_info=(LogInfo *) AcquireMagickMemory(sizeof(*log_info));
         if (log_info == (LogInfo *) NULL)
-          ThrowMagickFatalException(ResourceLimitFatalError,
-            "MemoryAllocationFailed",filename);
+          ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
         (void) ResetMagickMemory(log_info,0,sizeof(*log_info));
         log_info->path=ConstantString(filename);
         GetTimerInfo((TimerInfo *) &log_info->timer);
@@ -1482,7 +1477,7 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The log configuration filename.
+%    o filename: the log configuration filename.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1490,7 +1485,7 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
 static MagickBooleanType LoadLogLists(const char *filename,
   ExceptionInfo *exception)
 {
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
   return(LoadLogList(LogMap,"built-in",0,exception));
 #else
   const StringInfo
@@ -1644,7 +1639,7 @@ MagickExport LogEventType SetLogEventMask(const char *events)
 %
 %  A description of each parameter follows:
 %
-%    o format: The log record format.
+%    o format: the log record format.
 %
 */
 MagickExport void SetLogFormat(const char *format)
