@@ -66,7 +66,7 @@
 #include "magick/registry.h"
 #include "magick/resource_.h"
 #include "magick/semaphore.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 #include "magick/splay-tree.h"
 #include "magick/string_.h"
 #include "magick/token.h"
@@ -136,17 +136,18 @@ static MagickBooleanType
 */
 MagickExport void DestroyMagickList(void)
 {
-#if defined(MAGICKCORE_MODULES_SUPPORT)
-  DestroyModuleList();
-#endif
-#if !defined(MAGICKCORE_BUILD_MODULES)
-  UnregisterStaticModules();
-#endif
   AcquireSemaphoreInfo(&magick_semaphore);
   if (magick_list != (SplayTreeInfo *) NULL)
     magick_list=DestroySplayTree(magick_list);
+  instantiate_magick=MagickFalse;
   RelinquishSemaphoreInfo(magick_semaphore);
-  magick_semaphore=DestroySemaphoreInfo(magick_semaphore);
+  DestroySemaphoreInfo(&magick_semaphore);
+#if !defined(MAGICKCORE_BUILD_MODULES)
+  UnregisterStaticModules();
+#endif
+#if defined(MAGICKCORE_MODULES_SUPPORT)
+  DestroyModuleList();
+#endif
 }
 
 /*
@@ -230,9 +231,9 @@ MagickExport EncodeImageHandler *GetImageEncoder(const MagickInfo *magick_info)
 %
 %  A description of each parameter follows:
 %
-%    o magick: The image format we are searching for.
+%    o magick: the image format we are searching for.
 %
-%    o length: The length of the binary string.
+%    o length: the length of the binary string.
 %
 */
 MagickExport const char *GetImageMagick(const unsigned char *magick,
@@ -412,7 +413,7 @@ MagickExport MagickBooleanType GetMagickEndianSupport(
 %
 %  A description of each parameter follows:
 %
-%    o name: The image format we are looking for.
+%    o name: the image format we are looking for.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1014,7 +1015,7 @@ MagickExport MagickBooleanType IsMagickInstantiated(void)
 %
 %  A description of each parameter follows:
 %
-%    o path: The execution path of the current ImageMagick client.
+%    o path: the execution path of the current ImageMagick client.
 %
 %    o establish_signal_handlers: set to MagickTrue to use MagickCore's own
 %      signal handlers for common signals.
@@ -1269,7 +1270,7 @@ MagickExport void MagickCoreTerminus(void)
 %
 %  A description of each parameter follows:
 %
-%    o magick_info: The magick info.
+%    o magick_info: the magick info.
 %
 */
 MagickExport MagickInfo *RegisterMagickInfo(MagickInfo *magick_info)
