@@ -22,6 +22,13 @@
 extern "C" {
 #endif
 
+typedef enum
+{
+  UndefinedFormatType,
+  ImplicitFormatType,
+  ExplicitFormatType
+} MagickFormatType;
+
 typedef enum
 {
   NoThreadSupport = 0x0000,
@@ -69,6 +76,9 @@ typedef struct _MagickInfo
     blob_support,
     seekable_stream;
 
+  MagickFormatType
+    format_type;
+
   MagickStatusType
     thread_support;
 
