@@ -57,6 +57,7 @@ extern "C" {
 #define AcquireNextImage  PrependMagickMethod(AcquireNextImage)
 #define AcquireNexusIndexes  PrependMagickMethod(AcquireNexusIndexes)
 #define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
+#define AcquireOneCacheViewVirtualPixel  PrependMagickMethod(AcquireOneCacheViewVirtualPixel)
 #define AcquireOneMagickPixel  PrependMagickMethod(AcquireOneMagickPixel)
 #define AcquireOnePixel  PrependMagickMethod(AcquireOnePixel)
 #define AcquireOneVirtualPixel  PrependMagickMethod(AcquireOneVirtualPixel)
@@ -71,6 +72,7 @@ extern "C" {
 #define AcquireStreamInfo  PrependMagickMethod(AcquireStreamInfo)
 #define AcquireStringInfo  PrependMagickMethod(AcquireStringInfo)
 #define AcquireString  PrependMagickMethod(AcquireString)
+#define AcquireTimerInfo  PrependMagickMethod(AcquireTimerInfo)
 #define AcquireTokenInfo  PrependMagickMethod(AcquireTokenInfo)
 #define AcquireUniqueFilename  PrependMagickMethod(AcquireUniqueFilename)
 #define AcquireUniqueFileResource  PrependMagickMethod(AcquireUniqueFileResource)
@@ -211,13 +213,14 @@ extern "C" {
 #define DeleteNodeByValueFromSplayTree  PrependMagickMethod(DeleteNodeByValueFromSplayTree)
 #define DeleteNodeFromSplayTree  PrependMagickMethod(DeleteNodeFromSplayTree)
 #define DescribeImage  PrependMagickMethod(DescribeImage)
+#define DeskewImage  PrependMagickMethod(DeskewImage)
 #define DespeckleImage  PrependMagickMethod(DespeckleImage)
 #define DestroyBlob  PrependMagickMethod(DestroyBlob)
 #define DestroyCacheInfo  PrependMagickMethod(DestroyCacheInfo)
 #define DestroyCacheNexus  PrependMagickMethod(DestroyCacheNexus)
 #define DestroyCacheResources  PrependMagickMethod(DestroyCacheResources)
 #define DestroyCacheView  PrependMagickMethod(DestroyCacheView)
-#define DestroyCacheViewSet  PrependMagickMethod(DestroyCacheViewSet)
+#define DestroyCacheViewThreadSet  PrependMagickMethod(DestroyCacheViewThreadSet)
 #define DestroyCoderList  PrependMagickMethod(DestroyCoderList)
 #define DestroyColorList  PrependMagickMethod(DestroyColorList)
 #define DestroyConfigureList  PrependMagickMethod(DestroyConfigureList)
@@ -266,6 +269,7 @@ extern "C" {
 #define DestroyStringList  PrependMagickMethod(DestroyStringList)
 #define DestroyString  PrependMagickMethod(DestroyString)
 #define DestroyThresholdMap  PrependMagickMethod(DestroyThresholdMap)
+#define DestroyTimerInfo  PrependMagickMethod(DestroyTimerInfo)
 #define DestroyTokenInfo  PrependMagickMethod(DestroyTokenInfo)
 #define DestroyTypeList  PrependMagickMethod(DestroyTypeList)
 #define DestroyXMLTree  PrependMagickMethod(DestroyXMLTree)
@@ -366,6 +370,7 @@ extern "C" {
 #define GetConfigureInfoList  PrependMagickMethod(GetConfigureInfoList)
 #define GetConfigureInfo  PrependMagickMethod(GetConfigureInfo)
 #define GetConfigureList  PrependMagickMethod(GetConfigureList)
+#define GetConfigureOption  PrependMagickMethod(GetConfigureOption)
 #define GetConfigureOptions  PrependMagickMethod(GetConfigureOptions)
 #define GetConfigurePaths  PrependMagickMethod(GetConfigurePaths)
 #define GetConfigureValue  PrependMagickMethod(GetConfigureValue)
@@ -390,6 +395,7 @@ extern "C" {
 #define GetImageBoundingBox  PrependMagickMethod(GetImageBoundingBox)
 #define GetImageChannelDepth  PrependMagickMethod(GetImageChannelDepth)
 #define GetImageChannelDistortion  PrependMagickMethod(GetImageChannelDistortion)
+#define GetImageChannelDistortions  PrependMagickMethod(GetImageChannelDistortions)
 #define GetImageChannelExtrema  PrependMagickMethod(GetImageChannelExtrema)
 #define GetImageChannelMean  PrependMagickMethod(GetImageChannelMean)
 #define GetImageChannelRange  PrependMagickMethod(GetImageChannelRange)
@@ -615,7 +621,9 @@ extern "C" {
 #define IsTaintImage  PrependMagickMethod(IsTaintImage)
 #define LeastSquaresAddTerms  PrependMagickMethod(LeastSquaresAddTerms)
 #define LevelImageChannel  PrependMagickMethod(LevelImageChannel)
+#define LevelImageColors  PrependMagickMethod(LevelImageColors)
 #define LevelImage  PrependMagickMethod(LevelImage)
+#define LevelizeImageChannel  PrependMagickMethod(LevelizeImageChannel)
 #define LiberateMemory  PrependMagickMethod(LiberateMemory)
 #define LiberateSemaphoreInfo  PrependMagickMethod(LiberateSemaphoreInfo)
 #define LinearStretchImage  PrependMagickMethod(LinearStretchImage)
@@ -637,7 +645,6 @@ extern "C" {
 #define ListThresholdMapFile  PrependMagickMethod(ListThresholdMapFile)
 #define ListThresholdMaps  PrependMagickMethod(ListThresholdMaps)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
-#define LoadFontConfigFonts  PrependMagickMethod(LoadFontConfigFonts)
 #define LoadMimeLists  PrependMagickMethod(LoadMimeLists)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
@@ -785,7 +792,6 @@ extern "C" {
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
 #define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
-#define RegisterEXRImage  PrependMagickMethod(RegisterEXRImage)
 #define RegisterFAXImage  PrependMagickMethod(RegisterFAXImage)
 #define RegisterFITSImage  PrependMagickMethod(RegisterFITSImage)
 #define RegisterGIFImage  PrependMagickMethod(RegisterGIFImage)
@@ -924,6 +930,7 @@ extern "C" {
 #define SeparateImages  PrependMagickMethod(SeparateImages)
 #define SepiaToneImage  PrependMagickMethod(SepiaToneImage)
 #define SetBlobExempt  PrependMagickMethod(SetBlobExempt)
+#define SetBlobExtent  PrependMagickMethod(SetBlobExtent)
 #define SetCacheMethods  PrependMagickMethod(SetCacheMethods)
 #define SetCacheNexus  PrependMagickMethod(SetCacheNexus)
 #define SetCacheThreshold  PrependMagickMethod(SetCacheThreshold)
@@ -974,8 +981,11 @@ extern "C" {
 #define SetMagickRegistry  PrependMagickMethod(SetMagickRegistry)
 #define SetMagickResourceLimit  PrependMagickMethod(SetMagickResourceLimit)
 #define SetMonitorHandler  PrependMagickMethod(SetMonitorHandler)
+#define SetQuantumAlphaType  PrependMagickMethod(SetQuantumAlphaType)
 #define SetQuantumDepth  PrependMagickMethod(SetQuantumDepth)
+#define SetQuantumFormat  PrependMagickMethod(SetQuantumFormat)
 #define SetQuantumImageType  PrependMagickMethod(SetQuantumImageType)
+#define SetQuantumPad  PrependMagickMethod(SetQuantumPad)
 #define SetRandomKey  PrependMagickMethod(SetRandomKey)
 #define SetRandomTrueRandom  PrependMagickMethod(SetRandomTrueRandom)
 #define SetResampleFilterInterpolateMethod  PrependMagickMethod(SetResampleFilterInterpolateMethod)
@@ -1006,6 +1016,7 @@ extern "C" {
 #define SketchImage  PrependMagickMethod(SketchImage)
 #define SolarizeImage  PrependMagickMethod(SolarizeImage)
 #define SortColormapByIntensity  PrependMagickMethod(SortColormapByIntensity)
+#define SparseColorInterpolate  PrependMagickMethod(SparseColorInterpolate)
 #define SpliceImageIntoList  PrependMagickMethod(SpliceImageIntoList)
 #define SpliceImageList  PrependMagickMethod(SpliceImageList)
 #define SpliceImage  PrependMagickMethod(SpliceImage)
@@ -1032,6 +1043,7 @@ extern "C" {
 #define SyncCacheView  PrependMagickMethod(SyncCacheView)
 #define SyncImageList  PrependMagickMethod(SyncImageList)
 #define SyncImageOptions  PrependMagickMethod(SyncImageOptions)
+#define SyncImagePixelCache  PrependMagickMethod(SyncImagePixelCache)
 #define SyncImagePixels  PrependMagickMethod(SyncImagePixels)
 #define SyncImage  PrependMagickMethod(SyncImage)
 #define SyncImageProfiles  PrependMagickMethod(SyncImageProfiles)
@@ -1081,7 +1093,6 @@ extern "C" {
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
 #define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
-#define UnregisterEXRImage  PrependMagickMethod(UnregisterEXRImage)
 #define UnregisterFAXImage  PrependMagickMethod(UnregisterFAXImage)
 #define UnregisterFITSImage  PrependMagickMethod(UnregisterFITSImage)
 #define UnregisterGIFImage  PrependMagickMethod(UnregisterGIFImage)
