@@ -15,7 +15,7 @@
 %                                 July 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -172,7 +172,7 @@ MagickExport void DestroyMimeList(void)
     mime_list=DestroyLinkedList(mime_list,DestroyMimeElement);
   instantiate_mime=MagickFalse;
   RelinquishSemaphoreInfo(mime_semaphore);
-  mime_semaphore=DestroySemaphoreInfo(mime_semaphore);
+  DestroySemaphoreInfo(&mime_semaphore);
 }
 
 /*
@@ -203,7 +203,7 @@ MagickExport void DestroyMimeList(void)
 %    o magic: A binary string generally representing the first few characters
 %      of the image file or blob.
 %
-%    o length: The length of the binary signature.
+%    o length: the length of the binary signature.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -985,7 +985,7 @@ static MagickBooleanType LoadMimeList(const char *xml,const char *filename,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The font file name.
+%    o filename: the font file name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -993,7 +993,7 @@ static MagickBooleanType LoadMimeList(const char *xml,const char *filename,
 MagickExport MagickBooleanType LoadMimeLists(const char *filename,
   ExceptionInfo *exception)
 {
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
   return(LoadMimeList(MimeMap,"built-in",0,exception));
 #else
   const StringInfo
