@@ -113,6 +113,49 @@ static void
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   A c q u i r e M o d u l e I n f o                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireModuleInfo() allocates the ModuleInfo structure.
+%
+%  The format of the AcquireModuleInfo method is:
+%
+%      ModuleInfo *AcquireModuleInfo(const char *path,const char *tag)
+%
+%  A description of each parameter follows:
+%
+%    o path: the path associated with the tag.
+%
+%    o tag: a character string that represents the image format we are
+%      looking for.
+%
+*/
+MagickExport ModuleInfo *AcquireModuleInfo(const char *path,const char *tag)
+{
+  ModuleInfo
+    *module_info;
+
+  module_info=(ModuleInfo *) AcquireMagickMemory(sizeof(*module_info));
+  if (module_info == (ModuleInfo *) NULL)
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
+  (void) ResetMagickMemory(module_info,0,sizeof(*module_info));
+  if (path != (const char *) NULL)
+    module_info->path=ConstantString(path);
+  if (tag != (const char *) NULL)
+    module_info->tag=ConstantString(tag);
+  module_info->timestamp=time(0);
+  module_info->signature=MagickSignature;
+  return(module_info);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y M o d u l e L i s t                                         %
 %                                                                             %
 %                                                                             %
@@ -791,15 +834,8 @@ static MagickBooleanType InitializeModuleList(
           if (module_list == (SplayTreeInfo *) NULL)
             ThrowFatalException(ResourceLimitFatalError,
               "MemoryAllocationFailed");
-          module_info=(ModuleInfo *) AcquireMagickMemory(sizeof(*module_info));
-          if (module_info == (ModuleInfo *) NULL)
-            ThrowFatalException(ResourceLimitFatalError,
-              "MemoryAllocationFailed");
-          (void) ResetMagickMemory(module_info,0,sizeof(*module_info));
-          module_info->tag=ConstantString("[boot-strap]");
+          module_info=AcquireModuleInfo((const char *) NULL,"[boot-strap]");
           module_info->stealth=MagickTrue;
-          (void) time(&module_info->load_time);
-          module_info->signature=MagickSignature;
           status=AddValueToSplayTree(module_list,module_info->tag,module_info);
           if (status == MagickFalse)
             ThrowFatalException(ResourceLimitFatalError,
@@ -1064,16 +1100,12 @@ MagickExport MagickBooleanType OpenModule(const char *module,
   module_info=(ModuleInfo *) GetModuleInfo(module,exception);
   if (module_info != (ModuleInfo *) NULL)
     return(MagickTrue);
-  AcquireSemaphoreInfo(&module_semaphore);
   (void) CopyMagickString(module_name,module,MaxTextExtent);
   p=GetCoderInfo(module,exception);
   if (p != (CoderInfo *) NULL)
     (void) CopyMagickString(module_name,p->name,MaxTextExtent);
   if (GetValueFromSplayTree(module_list,module_name) != (void *) NULL)
-    {
-      RelinquishSemaphoreInfo(module_semaphore);
-      return(MagickTrue);  /* module already opened, return */
-    }
+    return(MagickTrue);  /* module already opened, return */
   /*
     Locate module.
   */
@@ -1084,43 +1116,26 @@ MagickExport MagickBooleanType OpenModule(const char *module,
   *path='\0';
   length=GetMagickModulePath(filename,MagickImageCoderModule,path,exception);
   if (length == 0)
-    {
-      RelinquishSemaphoreInfo(module_semaphore);
-      return(MagickFalse);
-    }
+    return(MagickFalse);
   /*
     Load module
   */
+  (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
+    "Opening module at path \"%s\"",path);
   handle=(ModuleHandle) lt_dlopen(path);
   if (handle == (ModuleHandle) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
         "UnableToLoadModule","`%s': %s",path,lt_dlerror());
-      RelinquishSemaphoreInfo(module_semaphore);
       return(MagickFalse);
     }
-  (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
-    "Opening module at path \"%s\"",path);
   /*
     Register module.
   */
-  module_info=(ModuleInfo *) AcquireMagickMemory(sizeof(*module_info));
-  if (module_info == (ModuleInfo *) NULL)
-    {
-      RelinquishSemaphoreInfo(module_semaphore);
-      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
-    }
-  (void) ResetMagickMemory(module_info,0,sizeof(*module_info));
-  module_info->path=ConstantString(path);
-  module_info->tag=ConstantString(module_name);
+  module_info=AcquireModuleInfo(path,module_name);
   module_info->handle=handle;
-  (void) time(&module_info->load_time);
-  module_info->signature=MagickSignature;
   if (RegisterModule(module_info,exception) == (ModuleInfo *) NULL)
-    {
-      RelinquishSemaphoreInfo(module_semaphore);
-      return(MagickFalse);
-    }
+    return(MagickFalse);
   /*
     Define RegisterFORMATImage method.
   */
@@ -1130,7 +1145,6 @@ MagickExport MagickBooleanType OpenModule(const char *module,
     {
       (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
         "UnableToRegisterImageFormat","`%s': %s",module_name,lt_dlerror());
-      RelinquishSemaphoreInfo(module_semaphore);
       return(MagickFalse);
     }
   (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
@@ -1145,7 +1159,6 @@ MagickExport MagickBooleanType OpenModule(const char *module,
     {
       (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
         "UnableToRegisterImageFormat","`%s': %s",module_name,lt_dlerror());
-      RelinquishSemaphoreInfo(module_semaphore);
       return(MagickFalse);
     }
   (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
@@ -1158,10 +1171,8 @@ MagickExport MagickBooleanType OpenModule(const char *module,
         "CoderSignatureMismatch","`%s': %8lx != %8lx",module_name,signature,
         MagickImageCoderSignature);
       module_info->unregister_module();
-      RelinquishSemaphoreInfo(module_semaphore);
       return(MagickFalse);
     }
-  RelinquishSemaphoreInfo(module_semaphore);
   return(MagickTrue);
 }
 
@@ -1275,7 +1286,7 @@ static const ModuleInfo *RegisterModule(const ModuleInfo *module_info,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  TagToCoderModuleName() munges a module tag and obtains the filename of the
-%  corresponding module module.
+%  corresponding module.
 %
 %  The format of the TagToCoderModuleName module is:
 %
@@ -1285,7 +1296,7 @@ static const ModuleInfo *RegisterModule(const ModuleInfo *module_info,
 %
 %    o tag: a character string representing the module tag.
 %
-%    o name: return the module module name here.
+%    o name: return the module name here.
 %
 */
 static void TagToCoderModuleName(const char *tag,char *name)
