@@ -33,7 +33,7 @@ MagickExport MagickProgressMonitor
 static inline MagickBooleanType QuantumTick(const MagickOffsetType offset,
   const MagickSizeType span)
 {
-  if (span < 100)
+  if (span <= 100)
     return(MagickTrue);
   if ((offset % ((span-1)/100)) == 0)
     return(MagickTrue);
