@@ -60,6 +60,7 @@
 #include "magick/list.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/montage.h"
 #include "magick/option.h"
 #include "magick/quantize.h"
@@ -373,6 +374,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
 
   MagickBooleanType
     concatenate,
+    proceed,
     status;
 
   MagickOffsetType
@@ -446,14 +448,9 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       break;
     image_list[i]=thumbnail;
     (void) SetImageProgressMonitor(image,progress_monitor,image->client_data);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(i,number_images) != MagickFalse))
-      {
-        status=image->progress_monitor(TileImageTag,i,number_images,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,TileImageTag,i,number_images);
+    if (proceed == MagickFalse)
+      break;
     image=DestroyImage(image);
   }
   if (i < (long) number_images)
@@ -677,8 +674,8 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       (void) ConcatenateMagickString(montage->directory,"\n",extent);
       tile++;
     }
-    progress_monitor=SetImageProgressMonitor(montage,
-      (MagickProgressMonitor) NULL,montage->client_data);
+    progress_monitor=SetImageProgressMonitor(montage,(MagickProgressMonitor)
+      NULL,montage->client_data);
     if (texture != (Image *) NULL)
       (void) TextureImage(montage,texture);
     if (montage_info->title != (char *) NULL)
