@@ -800,6 +800,7 @@ static const OptionInfo
   DitherOptions[] =
   {
     { "Undefined", (long) UndefinedDitherMethod, MagickTrue },
+    { "None", (long) NoDitherMethod, MagickFalse },
     { "FloydSteinberg", (long) FloydSteinbergDitherMethod, MagickFalse },
     { "Riemersma", (long) RiemersmaDitherMethod, MagickFalse },
     { (char *) NULL, (long) UndefinedEndian, MagickFalse }
@@ -1204,7 +1205,6 @@ static const OptionInfo
     { "Undefined", (long) UndefinedDistortion, MagickTrue },
     { "Barycentric", (long) BarycentricColorInterpolate, MagickFalse },
     { "Bilinear", (long) BilinearColorInterpolate, MagickFalse },
-    { "Polynomial", (long) PolynomialColorInterpolate, MagickFalse },
     { "Shepards", (long) ShepardsColorInterpolate, MagickFalse },
     { "Voronoi", (long) VoronoiColorInterpolate, MagickFalse },
     { (char *) NULL, (long) UndefinedResource, MagickFalse }
@@ -2163,6 +2163,9 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
       if ((flags & SigmaValue) != 0)
         image->ticks_per_second=(long) (geometry_info.sigma+0.5);
     }
+  option=GetImageOption(image_info,"bias");
+  if (option != (const char *) NULL)
+    image->bias=StringToDouble(option,QuantumRange);
   option=GetImageOption(image_info,"compose");
   if (option != (const char *) NULL)
     image->compose=(CompositeOperator) ParseMagickOption(MagickComposeOptions,
@@ -2187,6 +2190,9 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
   if (option != (const char *) NULL)
     image->interpolate=(InterpolatePixelMethod) ParseMagickOption(
       MagickInterpolateOptions,MagickFalse,option);
+  option=GetImageOption(image_info,"loop");
+  if (option != (const char *) NULL)
+    image->iterations=atol(option);
   option=GetImageOption(image_info,"tile-offset");
   if (option != (const char *) NULL)
     {
