@@ -1843,7 +1843,8 @@ MagickExport const char *GetImageProperty(const Image *image,
         image->properties);
       return(p);
     }
-  if (image->properties != (void *) NULL)
+  if ((image->properties != (void *) NULL) &&
+      (LocaleNCompare("fx:",property,3) != 0))
     {
       p=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
         image->properties,property);
@@ -2683,6 +2684,15 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         q+=FormatMagickString(q,extent,"%lu",image->depth);
         break;
       }
+      case 'A':
+      {
+        /*
+          Image alpha channel.
+        */
+        q+=FormatMagickString(q,extent,"%s",MagickOptionToMnemonic(
+          MagickBooleanOptions,(long) image->matte));
+        break;
+      }
       case 'C':
       {
         /*
@@ -3042,6 +3052,27 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
     ConstantString(property),ConstantString(value));
   switch (*property)
   {
+    case 'B':
+    case 'b':
+    {
+      if (LocaleCompare(property,"bias") == 0)
+        {
+          image->bias=StringToDouble(value,QuantumRange);
+          break;
+        }
+      break;
+    }
+    case 'C':
+    case 'c':
+    {
+      if (LocaleCompare(property,"compose") == 0)
+        {
+          image->compose=(CompositeOperator) ParseMagickOption(
+            MagickComposeOptions,MagickFalse,value);
+          break;
+        }
+      break;
+    }
     case 'D':
     case 'd':
     {
@@ -3109,6 +3140,16 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
         }
       break;
     }
+    case 'L':
+    case 'l':
+    {
+      if (LocaleCompare(property,"loop") == 0)
+        {
+          image->iterations=atol(value);
+          break;
+        }
+      break;
+    }
     case 'P':
     case 'p':
     {
