@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/color-private.h"
 #include "magick/cache.h"
 #include "magick/draw.h"
@@ -1009,8 +1010,8 @@ MagickExport MagickPixelPacket ResamplePixelColor(
     DQ = resample_filter->A*(2.0*U+1) + resample_filter->B*V;
 
     /* get the scanline of pixels for this v */
-    pixels=AcquireCacheViewPixels(resample_filter->view,u,v,1UL*uw,1,
-      resample_filter->exception);
+    pixels=AcquireCacheViewPixels(resample_filter->view,u,v,(unsigned long) uw,
+      1,resample_filter->exception);
     if (pixels == (const PixelPacket *) NULL)
       return(pixel);
     indexes=AcquireCacheViewIndexes(resample_filter->view);
@@ -1084,7 +1085,8 @@ MagickExport MagickPixelPacket ResamplePixelColor(
 %
 %  The input vectors are produced by either finding the derivitives of
 %  the distortion function, or the partial derivitives from a distortion
-%  mapping.
+%  mapping.  They do not need to be the orthogonal derivatives, but can be
+%  caclated using radial/angluar derivatives.
 %
 %  If   u,v =  DistortEquation(x,y)
 %  Then the scaling vectors are the function derivitives...
@@ -1296,8 +1298,7 @@ static void SetResampleFilter(ResampleFilter *resample_filter,
      being worked out.
 
      Future: Direct use of teh resize filters in "resize.c" to set the lookup
-     table.  This may require some scaling such as  x = sqrt(Q*PI/2048)
-     Note PI/2  is about 1.7 which seems to produce a better result.
+     table, based on the filters working support window.
   */
   r_scale = sqrt(1.0/(double)WLUT_WIDTH)/blur;
   r_scale *= 2; /* for 2 pixel radius of Improved Elliptical Formula */
@@ -1310,18 +1311,18 @@ static void SetResampleFilter(ResampleFilter *resample_filter,
   default:
     /*
       Fill the LUT with a 1D resize filter function
-      But make teh Sinc/Bessel tapered window 2.0
+      But make the Sinc/Bessel tapered window 2.0
       I also normalize the result so the filter is 1.0
     */
     resize_filter = AcquireResizeFilter(resample_filter->image,filter,
          (MagickRealType)1.0,MagickTrue,resample_filter->exception);
     if (resize_filter != (ResizeFilter *) NULL) {
       resample_filter->support = GetResizeFilterSupport(resize_filter);
-      resample_filter->support /= blur;
+      resample_filter->support /= blur; /* taken into account above */
       resample_filter->support *= resample_filter->support;
       resample_filter->support *= (double)WLUT_WIDTH/4;
       if ( resample_filter->support >= (double)WLUT_WIDTH )
-           resample_filter->support = (double)WLUT_WIDTH;
+           resample_filter->support = (double)WLUT_WIDTH;  /* hack */
       for(Q=0; Q<WLUT_WIDTH; Q++)
         if ( (double) Q < resample_filter->support )
           resample_filter->filter_lut[Q] = (double)
@@ -1336,8 +1337,8 @@ static void SetResampleFilter(ResampleFilter *resample_filter,
            ModuleError, "UnableToSetFilteringValue",
            "Fall back to default EWA gaussian filter");
     }
-    /* FALLTHRU */
-  case GaussianFilter:
+    /* FALLTHRU - on exception */
+  /*case GaussianFilter:*/
   case UndefinedFilter:
     /*
       Create Normal Gaussian 2D Filter Weighted Lookup Table.
@@ -1354,17 +1355,16 @@ static void SetResampleFilter(ResampleFilter *resample_filter,
     resample_filter->support = WLUT_WIDTH;
     break;
   }
-#if 0
-  /* Debug output of the filter weighting LUT
-     Gnuplot the LUT with hoizontal adjusted to 'r' using...
-       plot [0:1][0:1] "lut.dat" using (sqrt($0/1024)):1 with lines
-     THe filter values is normalized for comparision
-  */
-  for(Q=0; Q<WLUT_WIDTH; Q++)
-    printf("%lf\n", resample_filter->filter_lut[Q] //);
-                      /resample_filter->filter_lut[0] );
-  exit(0);
-#endif
+  if (GetImageArtifact(resample_filter->image,"resample:verbose")
+        != (const char *) NULL)
+    /* Debug output of the filter weighting LUT
+      Gnuplot the LUT with hoizontal adjusted to 'r' using...
+        plot [0:2][-.2:1] "lut.dat" using (sqrt($0/1024)*2):1 with lines
+      THe filter values is normalized for comparision
+    */
+    for(Q=0; Q<WLUT_WIDTH; Q++)
+      printf("%lf\n", resample_filter->filter_lut[Q]
+                        /resample_filter->filter_lut[0] );
   return;
 }
 
