@@ -18,7 +18,7 @@
 %                                 June 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -47,7 +47,7 @@
 #include "magick/memory_.h"
 #include "magick/semaphore.h"
 #include "magick/string_.h"
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
 #include <pthread.h>
 #endif
 #if defined(__WINDOWS__)
@@ -59,7 +59,7 @@
 */
 struct SemaphoreInfo
 {
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   pthread_mutex_t
     mutex;
 
@@ -84,13 +84,13 @@ struct SemaphoreInfo
 /*
   Static declaractions.
 */
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
 static pthread_mutex_t
   semaphore_mutex = PTHREAD_MUTEX_INITIALIZER;
 #endif
 
 #if defined(__WINDOWS__)
-static volatile LONG
+static LONG
   semaphore_mutex = 0;
 #endif
 
@@ -119,8 +119,12 @@ static volatile LONG
 MagickExport void AcquireSemaphoreInfo(SemaphoreInfo **semaphore_info)
 {
   assert(semaphore_info != (SemaphoreInfo **) NULL);
-#if defined(HAVE_PTHREAD)
-  (void) pthread_mutex_lock(&semaphore_mutex);
+#if defined(MAGICKCORE_HAVE_PTHREAD)
+  if (pthread_mutex_lock(&semaphore_mutex) != 0)
+    {
+      (void) fprintf(stderr,"pthread_mutex_lock failed %s\n",strerror(errno));
+      _exit(1);
+    }
 #endif
 #if defined(__WINDOWS__)
   while (InterlockedCompareExchange(&semaphore_mutex,1L,0L) != 0)
@@ -128,8 +132,12 @@ MagickExport void AcquireSemaphoreInfo(SemaphoreInfo **semaphore_info)
 #endif
   if (*semaphore_info == (SemaphoreInfo *) NULL)
     *semaphore_info=AllocateSemaphoreInfo();
-#if defined(HAVE_PTHREAD)
-  (void) pthread_mutex_unlock(&semaphore_mutex);
+#if defined(MAGICKCORE_HAVE_PTHREAD)
+  if (pthread_mutex_unlock(&semaphore_mutex) != 0)
+    {
+      (void) fprintf(stderr,"pthread_mutex_unlock failed %s\n",strerror(errno));
+      _exit(1);
+    }
 #endif
 #if defined(__WINDOWS__)
   InterlockedExchange(&semaphore_mutex,0L);
@@ -170,20 +178,12 @@ MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
   */
   semaphore_info=(SemaphoreInfo *) malloc(sizeof(SemaphoreInfo));
   if (semaphore_info == (SemaphoreInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=DestroyString(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(semaphore_info,0,sizeof(SemaphoreInfo));
   /*
     Initialize the semaphore.
   */
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   {
     int
       status;
@@ -195,23 +195,33 @@ MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
     if (status != 0)
       {
         free(semaphore_info);
-        return((SemaphoreInfo *) NULL);
+        ThrowFatalException(ResourceLimitFatalError,
+          "UnableToInitializeSemaphore");
       }
 #if defined(PTHREAD_MUTEX_RECURSIVE)
-    (void) pthread_mutexattr_settype(&mutex_info,PTHREAD_MUTEX_RECURSIVE);
+    status=pthread_mutexattr_settype(&mutex_info,PTHREAD_MUTEX_RECURSIVE);
+    if (status != 0)
+      {
+        (void) pthread_mutexattr_destroy(&mutex_info);
+        free(semaphore_info);
+        ThrowFatalException(ResourceLimitFatalError,
+          "UnableToInitializeSemaphore");
+      }
 #endif
     status=pthread_mutex_init(&semaphore_info->mutex,&mutex_info);
+    (void) pthread_mutexattr_destroy(&mutex_info);
     if (status != 0)
       {
         free(semaphore_info);
-        return((SemaphoreInfo *) NULL);
+        ThrowFatalException(ResourceLimitFatalError,
+          "UnableToInitializeSemaphore");
       }
-    (void) pthread_mutexattr_destroy(&mutex_info);
     semaphore_info->id=0;
   }
 #endif
 #if defined(__WINDOWS__)
   InitializeCriticalSection(&semaphore_info->mutex);
+  semaphore_info->id=0;
 #endif
   semaphore_info->reference_count=0;
   semaphore_info->signature=MagickSignature;
@@ -238,8 +248,13 @@ MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
 */
 MagickExport void DestroySemaphore(void)
 {
-#if defined(HAVE_PTHREAD)
-  (void) pthread_mutex_destroy(&semaphore_mutex);
+#if defined(MAGICKCORE_HAVE_PTHREAD)
+  if (pthread_mutex_destroy(&semaphore_mutex) != 0)
+    {
+      (void) fprintf(stderr,"pthread_mutex_destroy failed %s\n",
+        strerror(errno));
+      _exit(1);
+    }
 #endif
 }
 
@@ -258,40 +273,40 @@ MagickExport void DestroySemaphore(void)
 %
 %  The format of the DestroySemaphoreInfo method is:
 %
-%      SemaphoreInfo *DestroySemaphoreInfo(SemaphoreInfo *semaphore_info)
+%      void DestroySemaphoreInfo(SemaphoreInfo **semaphore_info)
 %
 %  A description of each parameter follows:
 %
 %    o semaphore_info: Specifies a pointer to an SemaphoreInfo structure.
 %
 */
-MagickExport SemaphoreInfo *DestroySemaphoreInfo(SemaphoreInfo *semaphore_info)
+MagickExport void DestroySemaphoreInfo(SemaphoreInfo **semaphore_info)
 {
-  assert(semaphore_info != (SemaphoreInfo *) NULL);
-  assert(semaphore_info->signature == MagickSignature);
-#if defined(HAVE_PTHREAD)
+  assert(semaphore_info != (SemaphoreInfo **) NULL);
+  assert((*semaphore_info) != (SemaphoreInfo *) NULL);
+  assert((*semaphore_info)->signature == MagickSignature);
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   (void) pthread_mutex_lock(&semaphore_mutex);
 #endif
 #if defined(__WINDOWS__)
   while (InterlockedCompareExchange(&semaphore_mutex,1L,0L) != 0)
     Sleep(10);
 #endif
-#if defined(HAVE_PTHREAD)
-  (void) pthread_mutex_destroy(&semaphore_info->mutex);
+#if defined(MAGICKCORE_HAVE_PTHREAD)
+  (void) pthread_mutex_destroy(&(*semaphore_info)->mutex);
 #endif
 #if defined(__WINDOWS__)
-  DeleteCriticalSection(&semaphore_info->mutex);
+  DeleteCriticalSection(&(*semaphore_info)->mutex);
 #endif
-  semaphore_info->signature=(~MagickSignature);
-  free(semaphore_info);
-  semaphore_info=(SemaphoreInfo *) NULL;
-#if defined(HAVE_PTHREAD)
+  (*semaphore_info)->signature=(~MagickSignature);
+  free(*semaphore_info);
+  *semaphore_info=(SemaphoreInfo *) NULL;
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   (void) pthread_mutex_unlock(&semaphore_mutex);
 #endif
 #if defined(__WINDOWS__)
   InterlockedExchange(&semaphore_mutex,0L);
 #endif
-  return(semaphore_info);
 }
 
 /*
@@ -315,7 +330,7 @@ MagickExport SemaphoreInfo *DestroySemaphoreInfo(SemaphoreInfo *semaphore_info)
 */
 MagickExport void InitializeSemaphore(void)
 {
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   (void) pthread_mutex_init(&semaphore_mutex,
     (const pthread_mutexattr_t *) NULL);
 #endif
@@ -347,7 +362,7 @@ MagickExport MagickBooleanType LockSemaphoreInfo(SemaphoreInfo *semaphore_info)
 {
   assert(semaphore_info != (SemaphoreInfo *) NULL);
   assert(semaphore_info->signature == MagickSignature);
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   {
     int
       status;
@@ -440,7 +455,7 @@ MagickExport MagickBooleanType UnlockSemaphoreInfo(
   if (semaphore_info->reference_count == 0)
     return(MagickFalse);
   semaphore_info->reference_count--;
-#if defined(HAVE_PTHREAD)
+#if defined(MAGICKCORE_HAVE_PTHREAD)
   {
     int
       status;
