@@ -54,6 +54,7 @@
 #include "magick/composite.h"
 #include "magick/composite-private.h"
 #include "magick/decorate.h"
+#include "magick/distort.h"
 #include "magick/draw.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -105,91 +106,29 @@
 MagickExport Image *AffineTransformImage(const Image *image,
   const AffineMatrix *affine_matrix,ExceptionInfo *exception)
 {
-  AffineMatrix
-    transform;
+  double
+    distort[6];
 
   Image
     *affine_image;
 
-  PointInfo
-    extent[4],
-    min,
-    max,
-    point;
-
-  register long
-    i;
-
-  assert(image != (const Image *) NULL);
+  /*
+    Affine transform image.
+  */
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(affine_matrix != (AffineMatrix *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  /*
-    Determine destination image bounding box.
-  */
-  extent[0].x=(double) image->page.x;
-  extent[0].y=(double) image->page.y;
-  extent[1].x=(double) (image->page.x+image->columns);
-  extent[1].y=(double) image->page.y;
-  extent[2].x=(double) (image->page.x+image->columns);
-  extent[2].y=(double) (image->page.y+image->rows);
-  extent[3].x=(double) image->page.x;
-  extent[3].y=(double) (image->page.y+image->rows);
-  for (i=0; i < 4; i++)
-  {
-    point=extent[i];
-    extent[i].x=(double) (point.x*affine_matrix->sx+point.y*affine_matrix->ry+
-      affine_matrix->tx);
-    extent[i].y=(double) (point.x*affine_matrix->rx+point.y*affine_matrix->sy+
-      affine_matrix->ty);
-  }
-  min=extent[0];
-  max=extent[0];
-  for (i=1; i < 4; i++)
-  {
-    if (min.x > extent[i].x)
-      min.x=extent[i].x;
-    if (min.y > extent[i].y)
-      min.y=extent[i].y;
-    if (max.x < extent[i].x)
-      max.x=extent[i].x;
-    if (max.y < extent[i].y)
-      max.y=extent[i].y;
-  }
-  affine_image=CloneImage(image,(unsigned long) (max.x-min.x+0.5),
-    (unsigned long) (max.y-min.y+0.5),MagickTrue,exception);
-  if (affine_image == (Image *) NULL)
-    return((Image *) NULL);
-  affine_image->background_color.opacity=(Quantum) TransparentOpacity;
-  (void) SetImageBackgroundColor(affine_image);
-  /*
-    Adjust transform translation for direct image to image transformation.
-    That is, pixel 0,0 translates correctly to its location in destination.
-  */
-  transform=(*affine_matrix);
-  transform.tx=extent[0].x-min.x;
-  transform.ty=extent[0].y-min.y;
-  /*
-    Affine transform image.
-  */
-  (void) DrawAffineImage(affine_image,image,&transform);
-  /*
-    Add offset to resulting image.
-  */
-  affine_image->page.x=(long) floor(min.x+0.5);
-  affine_image->page.y=(long) floor(min.y+0.5);
-  /*
-    Roughly calculate an appropriate virtual canvas (page) size.
-  */
-  affine_image->page.width=affine_image->columns;
-  if (affine_image->page.x > 0)
-    affine_image->page.width+=affine_image->page.x;
-  affine_image->page.height=affine_image->rows;
-  if (affine_image->page.y > 0)
-    affine_image->page.height+=affine_image->page.y;
+  distort[0]=affine_matrix->sx;
+  distort[1]=affine_matrix->rx;
+  distort[2]=affine_matrix->ry;
+  distort[3]=affine_matrix->sy;
+  distort[4]=affine_matrix->tx;
+  distort[5]=affine_matrix->ty;
+  affine_image=DistortImage(image,AffineProjectionDistortion,6,distort,
+    MagickTrue,exception);
   return(affine_image);
 }
 
@@ -303,8 +242,10 @@ static inline void CropToFitImage(Image **image,const MagickRealType x_shear,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DeskewImage() utilizes a radon transform to straighten an image and returns
-%  it.
+%  DeskewImage() removes skew from the image.  Skew is an artifact that
+%  occurs in scanned images because of the camera being misaligned,
+%  imperfections in the scanning or surface, or simply because the paper was
+%  not placed completely flat when scanned.
 %
 %  The format of the DeskewImage method is:
 %
@@ -315,7 +256,7 @@ static inline void CropToFitImage(Image **image,const MagickRealType x_shear,
 %
 %    o image: the image.
 %
-%    o threshold: deskewing threshold.
+%    o threshold: separate background from foreground.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -346,7 +287,7 @@ typedef struct _RadonInfo
     *cells;
 } RadonInfo;
 
-static void *DestroyRadonInfo(RadonInfo *radon_info)
+static RadonInfo *DestroyRadonInfo(RadonInfo *radon_info)
 {
   assert(radon_info != (RadonInfo *) NULL);
   switch (radon_info->type)
@@ -608,7 +549,7 @@ static inline MagickBooleanType SetRadonCell(const RadonInfo *radon_info,
   i=(off_t) radon_info->height*x+y;
   if ((i < 0) ||
       ((MagickSizeType) (i*sizeof(*radon_info->cells)) >= radon_info->length))
-    return(0);
+    return(MagickFalse);
   if (radon_info->type != DiskCache)
     {
       radon_info->cells[i]=value;
@@ -1058,6 +999,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
     *rotate_image;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -1088,6 +1030,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
     Integral rotate the image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   rotate_view=AcquireCacheViewThreadSet(rotate_image);
   switch (rotations)
@@ -1134,8 +1077,17 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             sizeof(*indexes));
         if (SyncCacheView(rotate_view[id]) == MagickFalse)
           status=MagickFalse;
-        if (SetImageProgress(image,RotateImageTag,y,image->rows) == MagickFalse)
-          status=MagickFalse;
+        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+          {
+            MagickBooleanType
+              proceed;
+
+            #pragma omp critical
+            proceed=SetImageProgress(image,RotateImageTag,progress++,
+              image->rows);
+            if (proceed == MagickFalse)
+              status=MagickFalse;
+          }
       }
       break;
     }
@@ -1182,8 +1134,17 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             image->columns*sizeof(*rotate_indexes));
         if (SyncCacheView(rotate_view[id]) == MagickFalse)
           status=MagickFalse;
-        if (SetImageProgress(image,RotateImageTag,y,image->rows) == MagickFalse)
-          status=MagickFalse;
+        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+          {
+            MagickBooleanType
+              proceed;
+
+            #pragma omp critical
+            proceed=SetImageProgress(image,RotateImageTag,progress++,
+              image->rows);
+            if (proceed == MagickFalse)
+              status=MagickFalse;
+          }
       }
       Swap(page.width,page.height);
       Swap(page.x,page.y);
@@ -1237,8 +1198,17 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             rotate_indexes[image->columns-x-1]=indexes[x];
         if (SyncCacheView(rotate_view[id]) == MagickFalse)
           status=MagickFalse;
-        if (SetImageProgress(image,RotateImageTag,y,image->rows) == MagickFalse)
-          status=MagickFalse;
+        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+          {
+            MagickBooleanType
+              proceed;
+
+            #pragma omp critical
+            proceed=SetImageProgress(image,RotateImageTag,progress++,
+              image->rows);
+            if (proceed == MagickFalse)
+              status=MagickFalse;
+          }
       }
       if (page.width != 0)
         page.x=(long) (page.width-rotate_image->columns-page.x);
@@ -1291,8 +1261,17 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             rotate_indexes[image->columns-x-1]=indexes[x];
         if (SyncCacheView(rotate_view[id]) == MagickFalse)
           status=MagickFalse;
-        if (SetImageProgress(image,RotateImageTag,y,image->rows) == MagickFalse)
-          status=MagickFalse;
+        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+          {
+            MagickBooleanType
+              proceed;
+
+            #pragma omp critical
+            proceed=SetImageProgress(image,RotateImageTag,progress++,
+              image->rows);
+            if (proceed == MagickFalse)
+              status=MagickFalse;
+          }
       }
       Swap(page.width,page.height);
       Swap(page.x,page.y);
@@ -1398,6 +1377,7 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
     direction;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -1418,7 +1398,11 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
     &background);
   if (image->colorspace == CMYKColorspace)
     ConvertRGBToCMYK(&background);
+  /*
+    XShear image.
+  */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for private(direction)
   for (y=0; y < (long) height; y++)
@@ -1541,8 +1525,16 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,XShearImageTag,y,height) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,XShearImageTag,progress++,height);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -1592,6 +1584,7 @@ static MagickBooleanType YShearImage(Image *image,const MagickRealType degrees,
     direction;
 
   long
+    progress,
     x;
 
   MagickBooleanType
@@ -1612,7 +1605,11 @@ static MagickBooleanType YShearImage(Image *image,const MagickRealType degrees,
     &background);
   if (image->colorspace == CMYKColorspace)
     ConvertRGBToCMYK(&background);
+  /*
+    Y Shear image.
+  */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for private(direction)
   for (x=0; x < (long) width; x++)
@@ -1735,8 +1732,16 @@ static MagickBooleanType YShearImage(Image *image,const MagickRealType degrees,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,YShearImageTag,x,width) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,YShearImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
