@@ -1092,7 +1092,7 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
     }
   }
   /* Set channel levels from extra comma seperated arguments
-     Default to 2, or single value given, or individual channel values
+     Default to 2, the single value given, or individual channel values
   */
 #if 1
   { /* parse directly as a comma seperated list of integers */
@@ -1121,10 +1121,10 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
         levels.green = (unsigned long) strtol(p, &p, 10), (void)(*p == ',' && p++);
       if ((channel & BlueChannel) != 0)
         levels.blue = (unsigned long) strtol(p, &p, 10),  (void)(*p == ',' && p++);
-      if ((channel & OpacityChannel) != 0)
-        levels.opacity = (unsigned long) strtol(p, &p, 10), (void)(*p == ',' && p++);
       if ((channel & IndexChannel) != 0 && image->colorspace == CMYKColorspace)
         levels.index=(unsigned long) strtol(p, &p, 10), (void)(*p == ',' && p++);
+      if ((channel & OpacityChannel) != 0)
+        levels.opacity = (unsigned long) strtol(p, &p, 10), (void)(*p == ',' && p++);
     }
   }
 #else
@@ -1307,14 +1307,8 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
     min_threshold,
     max_threshold;
 
-  register long
-    x;
-
-  register IndexPacket
-    *indexes;
-
-  register PixelPacket
-    *q;
+  ViewInfo
+    *image_view;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -1334,12 +1328,12 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
     max_threshold=min_threshold;
   if (strchr(thresholds,'%') != (char *) NULL)
     {
-      max_threshold*=(0.01f*QuantumRange);
-      min_threshold*=(0.01f*QuantumRange);
+      max_threshold*=(0.01*QuantumRange);
+      min_threshold*=(0.01*QuantumRange);
     }
   else
-    if ((min_threshold <= 8) && ((max_threshold == min_threshold) ||
-        (max_threshold == 1)))
+    if (((max_threshold == min_threshold) || (max_threshold == 1)) &&
+        (min_threshold <= 8))
       {
         /*
           Backward Compatibility -- ordered-dither -- IM v 6.2.9-6.
@@ -1347,25 +1341,39 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
         status=OrderedPosterizeImageChannel(image,channel,thresholds,exception);
         return(status);
       }
+  status=MagickTrue;
   if (channel == AllChannels)
     {
-      IndexPacket
-        index;
-
-      MagickRealType
-        intensity;
-
       if (AcquireImageColormap(image,2) == MagickFalse)
         ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
           image->filename);
+      image_view=AcquireCacheView(image);
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        register IndexPacket
+          *indexes;
+
+        register long
+          x;
+
+        register PixelPacket
+          *q;
+
+        q=GetCacheViewPixels(image_view,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
-        indexes=GetIndexes(image);
+          {
+            status=MagickFalse;
+            break;
+          }
+        indexes=GetCacheViewIndexes(image_view);
         for (x=0; x < (long) image->columns; x++)
         {
+          IndexPacket
+            index;
+
+          MagickRealType
+            intensity;
+
           intensity=(MagickRealType) PixelIntensityToQuantum(q);
           if (intensity < min_threshold)
             threshold.index=min_threshold;
@@ -1378,25 +1386,41 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
           indexes[x]=index;
           *q++=image->colormap[(long) index];
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view) == MagickFalse)
+          status=MagickFalse;
         proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
         if (proceed == MagickFalse)
+          status=MagickFalse;
+        if (status == MagickFalse)
           break;
       }
-      return(MagickTrue);
+      image_view=DestroyCacheView(image_view);
+      return(status);
     }
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     {
       InheritException(exception,&image->exception);
       return(MagickFalse);
     }
+  image_view=AcquireCacheView(image);
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    register IndexPacket
+      *indexes;
+
+    register long
+      x;
+
+    register PixelPacket
+      *q;
+
+    q=GetCacheViewPixels(image_view,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetIndexes(image);
+      {
+        status=MagickFalse;
+        break;
+      }
+    indexes=GetCacheViewIndexes(image_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -1473,13 +1497,16 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
           threshold.index ? 0 : QuantumRange);
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
+    if (SyncCacheView(image_view) == MagickFalse)
+      status=MagickFalse;
     proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
     if (proceed == MagickFalse)
+      status=MagickFalse;
+    if (status == MagickFalse)
       break;
   }
-  return(MagickTrue);
+  image_view=DestroyCacheView(image_view);
+  return(status);
 }
 
 /*
