@@ -567,7 +567,7 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
 %
 %  A description of each parameter follows:
 %
-%    o path: The path.
+%    o path: the path.
 %
 */
 MagickExport MagickBooleanType IsGlob(const char *path)
@@ -575,6 +575,8 @@ MagickExport MagickBooleanType IsGlob(const char *path)
   MagickBooleanType
     status;
 
+  if (IsAccessible(path) != MagickFalse)
+    return(MagickFalse);
   status=(strchr(path,'*') != (char *) NULL) ||
     (strchr(path,'?') != (char *) NULL) ||
     (strchr(path,'{') != (char *) NULL) ||
