@@ -27,9 +27,11 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2008 ImageMagick Studio LLC"
-#define MagickLibVersion  0x642
-#define MagickLibVersionText  "6.4.2"
-#define MagickLibVersionNumber  6,4,2,9
+#define MagickLibVersion  0x643
+#define MagickLibVersionText  "6.4.3"
+#define MagickLibVersionNumber  1,0,0
+#define MagickReleaseDate  "2008-08-30"
+#define MagickChangeDate   "20080827"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -46,7 +48,6 @@ extern "C" {
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
-#define MagickReleaseDate  "08/15/08"
 #if !defined(MAGICKCORE_HDRI_SUPPORT)
 #define MagickHDRISupport ""
 #else
@@ -61,7 +62,7 @@ extern "C" {
 #define MagickVersion MagickPackageName " " MagickLibVersionText " " \
   MagickReleaseDate " " MagickQuantumDepth " " MagickSupport \
   "http://www.imagemagick.org"
-#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.4.2/index.html"
+#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.4.3/index.html"
 
 extern MagickExport char
   *GetMagickHomeURL(void);
