@@ -17,7 +17,7 @@
 %                               December 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -88,7 +88,7 @@ int main(int argc,char **argv)
     *option;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   ImageInfo
     *image_info;
@@ -100,28 +100,30 @@ int main(int argc,char **argv)
   register long
     i;
 
-  InitializeMagick(*argv);
-  GetExceptionInfo(&exception);
+  MagickCoreGenesis(*argv,MagickTrue);
+  exception=AcquireExceptionInfo();
   regard_warnings=MagickFalse;
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
     if ((strlen(option) == 1) || ((*option != '-') && (*option != '+')))
       continue;
+    if (LocaleCompare("debug",option+1) == 0)
+      (void) SetLogEventMask(argv[++i]);
     if (LocaleCompare("regard-warnings",option+1) == 0)
       regard_warnings=MagickTrue;
   }
   image_info=AcquireImageInfo();
-  status=ConjureImageCommand(image_info,argc,argv,(char **) NULL,&exception);
-  if ((status == MagickFalse) || (exception.severity != UndefinedException))
+  status=ConjureImageCommand(image_info,argc,argv,(char **) NULL,exception);
+  if (exception->severity != UndefinedException)
     {
-      if ((exception.severity < ErrorException) &&
-          (regard_warnings == MagickFalse))
+      if ((exception->severity > ErrorException) ||
+          (regard_warnings != MagickFalse))
         status=MagickTrue;
-      CatchException(&exception);
+      CatchException(exception);
     }
   image_info=DestroyImageInfo(image_info);
-  (void) DestroyExceptionInfo(&exception);
-  DestroyMagick();
-  return(status == MagickFalse ? 1 : 0);
+  exception=DestroyExceptionInfo(exception);
+  MagickCoreTerminus();
+  return(status == MagickFalse ? 0 : 1);
 }
