@@ -734,22 +734,13 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("seed",option+1) == 0)
           {
-            unsigned long
-              seed;
-
             if (*option == '+')
-              {
-                seed=(unsigned long) time((time_t *) NULL);
-                SeedPseudoRandomGenerator(seed);
-                break;
-              }
+              break;
             i++;
             if (i == (long) (argc-1))
               ThrowCompareException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompareInvalidArgumentException(option,argv[i]);
-            seed=(unsigned long) atol(argv[i]);
-            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("set",option+1) == 0)
