@@ -1283,22 +1283,13 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("seed",option+1) == 0)
           {
-            unsigned long
-              seed;
-
             if (*option == '+')
-              {
-                seed=(unsigned long) time((time_t *) NULL);
-                SeedPseudoRandomGenerator(seed);
-                break;
-              }
+              break;
             i++;
             if (i == (long) (argc-1))
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            seed=(unsigned long) atol(argv[i]);
-            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("sharpen",option+1) == 0)
