@@ -281,6 +281,7 @@ static void ConvertUsage(void)
     },
     *sequence_operators[]=
     {
+      "-affinity filename   transform image colors to match this set of colors",
       "-append              append an image sequence",
       "-average             average an image sequence",
       "-clut                apply a color lookup table to the image",
@@ -291,7 +292,6 @@ static void ConvertUsage(void)
       "-deconstruct         break down an image sequence into constituent parts",
       "-flatten             flatten a sequence of images",
       "-fx expression       apply mathematical expression to an image channel(s)",
-      "-map filename        transform image colors to match this set of colors",
       "-morph value         morph an image sequence",
       "-mosaic              create a mosaic from an image sequence",
       "-process arguments   process the image with a custom image filter",
@@ -2154,22 +2154,13 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("seed",option+1) == 0)
           {
-            unsigned long
-              seed;
-
             if (*option == '+')
-              {
-                seed=(unsigned long) time((time_t *) NULL);
-                SeedPseudoRandomGenerator(seed);
-                break;
-              }
+              break;
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowConvertInvalidArgumentException(option,argv[i]);
-            seed=(unsigned long) atol(argv[i]);
-            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("segment",option+1) == 0)
