@@ -1123,22 +1123,13 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("seed",option+1) == 0)
           {
-            unsigned long
-              seed;
-
             if (*option == '+')
-              {
-                seed=(unsigned long) time((time_t *) NULL);
-                SeedPseudoRandomGenerator(seed);
-                break;
-              }
+              break;
             i++;
             if (i == (long) (argc-1))
               ThrowImportException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowImportInvalidArgumentException(option,argv[i]);
-            seed=(unsigned long) atol(argv[i]);
-            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("silent",option+1) == 0)
