@@ -78,6 +78,7 @@ extern WandExport MagickBooleanType
   MagickAddNoiseImage(MagickWand *,const NoiseType),
   MagickAddNoiseImageChannel(MagickWand *,const ChannelType,const NoiseType),
   MagickAffineTransformImage(MagickWand *,const DrawingWand *),
+  MagickAffinityImage(MagickWand *,const MagickWand *,const DitherMethod),
   MagickAnnotateImage(MagickWand *,const DrawingWand *,const double,
     const double,const double,const char *),
   MagickAnimateImages(MagickWand *,const char *),
@@ -176,7 +177,6 @@ extern WandExport MagickBooleanType
   MagickLiquidRescaleImage(MagickWand *,const unsigned long,const unsigned long,
     const double,const double),
   MagickMagnifyImage(MagickWand *),
-  MagickMapImage(MagickWand *,const MagickWand *,const MagickBooleanType),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
   MagickModulateImage(MagickWand *,const double,const double,const double),
