@@ -90,7 +90,7 @@ static void MontageUsage(void)
       "-help                print program options",
       "-list type           print a list of supported option arguments",
       "-log format          format of debugging information",
-			"-version             print version information",
+      "-version             print version information",
       (char *) NULL
     },
     *operators[]=
@@ -1287,22 +1287,13 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("seed",option+1) == 0)
           {
-            unsigned long
-              seed;
-
             if (*option == '+')
-              {
-                seed=(unsigned long) time((time_t *) NULL);
-                SeedPseudoRandomGenerator(seed);
-                break;
-              }
+              break;
             i++;
             if (i == (long) (argc-1))
               ThrowMontageException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowMontageInvalidArgumentException(option,argv[i]);
-            seed=(unsigned long) atol(argv[i]);
-            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("scenes",option+1) == 0)
